import * as i3$1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Inject, Component, Directive, Input, NgModule } from '@angular/core';
import * as i4 from '@angular/forms';
import { FormBuilder, FormControl, Validators, FormGroup, FormsModule, ReactiveFormsModule, FormArray } from '@angular/forms';
import * as i1$1 from '@angular/router';
import { RouterModule } from '@angular/router';
import * as i3 from '@ngx-translate/core';
import { TranslateModule } from '@ngx-translate/core';
import { __awaiter } from 'tslib';
import * as i1 from '@angular/common/http';
import { HttpClient, HttpErrorResponse } from '@angular/common/http';
import { Subject, lastValueFrom, catchError, throwError } from 'rxjs';
import jwt_decode from 'jwt-decode';

const DEFAULT_ROUTES = {
    login: '/auth/login',
    logout: '/auth/logout',
    register: '/auth/register',
    requestPassword: '/auth/request-password',
    resetPassword: '/auth/reset-password',
    loginRedirect: '/',
    logoutRedirect: '/auth/login',
    requestPasswordRedirect: '/auth/login'
};

/**
 * This is not a real service, but it looks like it from the outside.
 * It's just an InjectionTToken used to import the config object, provided from the outside
 */
const ConfigServiceInjector = new InjectionToken('StrapiAuthConfig');
class ConfigService {
    constructor() { }
    applyRoutesConfig(config) {
        if (config.routes) {
            const merged = Object.assign(Object.assign({}, DEFAULT_ROUTES), config.routes);
            config.routes = merged;
        }
        else {
            config.routes = DEFAULT_ROUTES;
        }
    }
}
ConfigService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: ConfigService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
ConfigService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: ConfigService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: ConfigService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class TokenService {
    constructor() { }
    /**
     * Return token if given
     */
    getToken() {
        if (!this.token) {
            this.token = sessionStorage.getItem('token') || null;
            return this.token;
        }
        return this.token;
    }
    /**
     * Set token variable and write token to local storage
     */
    setToken(token) {
        this.token = token;
        sessionStorage.setItem('token', token);
    }
    /**
     * Delete token in local storage
     */
    deleteToken() {
        sessionStorage.removeItem('token');
    }
    /**
     * Decode token
     */
    decodeToken(token) {
        try {
            return jwt_decode(token);
        }
        catch (error) {
            return;
        }
    }
}
TokenService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: TokenService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
TokenService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: TokenService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: TokenService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class AuthService {
    // TODO: Add error handling for login and register post
    // TODO: Cleanup AuthService
    constructor(httpClient, handler, router, tokenService, configService, config) {
        this.httpClient = httpClient;
        this.handler = handler;
        this.router = router;
        this.tokenService = tokenService;
        this.configService = configService;
        this.config = config;
        this.authState = new Subject();
        this.userState = new Subject();
        this.strapiAuthConfig = config;
        this.configService.applyRoutesConfig(this.strapiAuthConfig);
        this.apiUrl = this.config.strapi_base_url || 'http://localhost:1337';
        // Requests wont get intercepted
        this.authHttpClient = new HttpClient(handler);
        const token = this.tokenService.getToken();
        if (token) {
            this.isAuthenticated = true;
            this.authState.next();
        }
    }
    /**
     * Return AuthState Promise
     */
    get AuthState() {
        return this.authState;
    }
    /**
     * Return AuthState Promise
     */
    get UserState() {
        return this.userState;
    }
    /**
     * Return login redirect url
     */
    get LoginRedirectUrl() {
        return this.strapiAuthConfig.routes.loginRedirect || '/';
    }
    /**
     * Return login url
     */
    get LoginUrl() {
        return this.strapiAuthConfig.routes.login || 'auth/login';
    }
    /**
     * Return logout url
     */
    get LogoutUrl() {
        return this.strapiAuthConfig.routes.login || 'auth/logout';
    }
    /**
     * Return logout redirect url
     */
    get LogoutRedirectUrl() {
        return this.strapiAuthConfig.routes.logoutRedirect || '/';
    }
    /**
     * Return register url
     */
    get RegisterUrl() {
        return this.strapiAuthConfig.routes.register || 'auth/register';
    }
    /**
     * Return request password url
     */
    get RequestPasswordUrl() {
        return (this.strapiAuthConfig.routes.requestPassword || 'auth/request-password');
    }
    /**
     * Return request password redirect url
     */
    get RequestPasswordRedirectUrl() {
        return this.strapiAuthConfig.routes.requestPasswordRedirect || '/';
    }
    /**
     * Return reset password url
     */
    get ResetPasswordUrl() {
        return this.strapiAuthConfig.routes.resetPassword || 'auth/reset-password';
    }
    /**
     * Login user with given credentials
     * and store jwt token and user data
     */
    login(loginReq) {
        return __awaiter(this, void 0, void 0, function* () {
            const res = yield this.postLogin(loginReq);
            if (res) {
                this.setTokenResponse(res);
            }
        });
    }
    /**
     * Login user using external provider
     * like google / facebook / microsoft / github
     */
    callbackProviderLogin(params, provider) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const res = (yield lastValueFrom(this.authHttpClient.get(this.apiUrl + '/auth/' + provider + '/callback?' + params)));
                if (res) {
                    this.setTokenResponse(res);
                }
            }
            catch (error) {
                console.error(error);
                return;
            }
        });
    }
    /**
     * Register new user with given data
     *
     * If registration has jwt token and user data in response
     * then store token and show user as logged in
     *
     */
    register(req) {
        return __awaiter(this, void 0, void 0, function* () {
            const res = yield this.postRegister(req);
            if (res) {
                this.setTokenResponse(res);
            }
        });
    }
    /**
     * Logout user
     */
    logout() {
        return __awaiter(this, void 0, void 0, function* () {
            this.isAuthenticated = false;
            this.user = null;
            this.authState.next();
            this.tokenService.deleteToken();
        });
    }
    /**
     * Update user profile
     */
    updateProfile(updateReq) {
        return __awaiter(this, void 0, void 0, function* () {
            const res = yield this.updateUser(updateReq);
            if (res) {
                this.user = res;
                this.userState.next();
            }
        });
    }
    /**
     * Request password reset mail
     */
    requestPasswordReset(email) {
        return __awaiter(this, void 0, void 0, function* () {
            const res = yield this.postRequestPasswordReset(email);
        });
    }
    /**
     * Reset user password
     */
    resetPassword(passwordResetReq) {
        return __awaiter(this, void 0, void 0, function* () {
            const res = yield this.postResetPassword(passwordResetReq);
        });
    }
    /**
     * return user obj
     */
    getUser() {
        return this.user;
    }
    /**
     * Load own user obj
     */
    loadUser() {
        return __awaiter(this, void 0, void 0, function* () {
            this.requestUser().then((user) => {
                if (user) {
                    this.user = user;
                    this.userState.next();
                }
            });
        });
    }
    /**
     * Write token to store and
     * call auth state subject
     */
    setTokenResponse(res) {
        if (res.jwt && res.user) {
            this.user = res.user;
            this.isAuthenticated = true;
            this.authState.next();
            this.userState.next();
            this.tokenService.setToken(res.jwt);
        }
    }
    /**
     * Call API for own user obj
     * and return it
     */
    requestUser() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const res = (yield lastValueFrom(this.httpClient.get(this.apiUrl + '/users/me', {})));
                return res;
            }
            catch (error) {
                throw new HttpErrorResponse(error);
            }
        });
    }
    /**
     * Update user
     */
    updateUser(updateReq) {
        return __awaiter(this, void 0, void 0, function* () {
            // TODO: Check if functionality is given
            // Updating a user (authenticated user) profile is currently not built into strapi (in that way)
            try {
                const res = (yield lastValueFrom(this.httpClient.put(this.apiUrl + '/users/me', updateReq)));
                return res;
            }
            catch (error) {
                throw new HttpErrorResponse(error);
            }
        });
    }
    /**
     * Login user and request token
     */
    postLogin(loginReq) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const res = (yield lastValueFrom(this.authHttpClient.post(this.apiUrl + '/auth/local', loginReq)));
                return res;
            }
            catch (error) {
                throw new HttpErrorResponse(error);
            }
        });
    }
    /**
     * Register new user
     */
    postRegister(registerReq) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const res = (yield lastValueFrom(this.authHttpClient.post(this.apiUrl + '/auth/local/register', {
                    username: registerReq.username,
                    email: registerReq.email,
                    password: registerReq.password
                })));
                return res;
            }
            catch (error) {
                throw new HttpErrorResponse(error);
            }
        });
    }
    /**
     * Request password reset
     */
    postRequestPasswordReset(email) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const res = (yield lastValueFrom(this.authHttpClient.post(this.apiUrl + '/auth/forgot-password', {
                    email
                })));
                return res;
            }
            catch (error) {
                throw new HttpErrorResponse(error);
            }
        });
    }
    /**
     * Reset password
     */
    postResetPassword(passwordResetReq) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const res = (yield lastValueFrom(this.authHttpClient.post(this.apiUrl + '/auth/reset-password', passwordResetReq)));
                return res;
            }
            catch (error) {
                throw new HttpErrorResponse(error);
            }
        });
    }
}
AuthService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: AuthService, deps: [{ token: i1.HttpClient }, { token: i1.HttpBackend }, { token: i1$1.Router }, { token: TokenService }, { token: ConfigService }, { token: ConfigServiceInjector }], target: i0.ɵɵFactoryTarget.Injectable });
AuthService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: AuthService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: AuthService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () {
        return [{ type: i1.HttpClient }, { type: i1.HttpBackend }, { type: i1$1.Router }, { type: TokenService }, { type: ConfigService }, { type: undefined, decorators: [{
                        type: Inject,
                        args: [ConfigServiceInjector]
                    }] }];
    } });

class ProfileComponent {
    constructor(authService, translate) {
        this.authService = authService;
        this.translate = translate;
        this.form = new FormBuilder().group({
            firstname: new FormControl(),
            lastname: new FormControl(),
            email: new FormControl(),
            username: new FormControl()
        });
        this.passwordForm = new FormBuilder().group({
            password: new FormControl('', [
                Validators.required,
                Validators.pattern('(?=.*[a-z])(?=.*[A-Z])(?=.*[0-9])(?=.*[$@$!%*?&])[A-Za-z\\d$@$!%*?&].{8,}')
            ]),
            rePass: new FormControl('', [
                Validators.required,
                Validators.pattern('(?=.*[a-z])(?=.*[A-Z])(?=.*[0-9])(?=.*[$@$!%*?&])[A-Za-z\\d$@$!%*?&].{8,}')
            ]),
            oldPassword: new FormControl()
        });
        this.userObj = {
            firstname: null,
            lastname: null,
            email: null,
            username: null,
            password: null,
            password_confirmation: null,
            oldPassword: null,
            provider: null
        };
        this.redirectDelay = 0;
        this.showMessages = {
            error: true
        };
        // TODO: Create error component for displaying errors
        // TODO: Add opt in error notifications
        this.submitted = false;
        this.passwordSubmitted = false;
        this.errors = [];
        this.messages = [];
        this.config = {
            firstnameRequired: false,
            firstnameMinLength: 2,
            firstnameMaxLength: 100,
            lastnameRequired: false,
            lastnameMinLength: 2,
            lastnameMaxLength: 100,
            usernameRequired: true,
            usernameMinLength: 2,
            usernameMaxLength: 100,
            emailRequired: true,
            passwordRequired: true,
            passwordMinLength: 6,
            passwordMaxLength: 60
        };
    }
    ngOnInit() {
        // Import existing user obj
        this.oldUserObj = this.authService.getUser();
        if (this.oldUserObj) {
            this.userObj = {
                firstname: null,
                lastname: null,
                username: this.oldUserObj.username,
                email: this.oldUserObj.email,
                password: null,
                password_confirmation: null,
                oldPassword: null,
                provider: null
            };
        }
        // Hook on update from user service
        this.authService.UserState.subscribe(() => {
            this.oldUserObj = this.authService.getUser();
            this.userObj = {
                firstname: null,
                lastname: null,
                username: this.oldUserObj.username,
                email: this.oldUserObj.email,
                password: null,
                password_confirmation: null,
                oldPassword: null,
                provider: null
            };
        });
    }
    ngOnDestroy() { }
    /**
     * Update UserData if changed
     */
    update() {
        this.clearErrors();
        this.submitted = true;
        const updateRequest = {
            username: this.userObj.username &&
                this.oldUserObj.username !== this.userObj.username
                ? this.userObj.username
                : null,
            email: this.userObj.email && this.oldUserObj.email !== this.userObj.email
                ? this.userObj.email
                : null,
            password: null,
            oldPassword: null
        };
        if (!updateRequest.username && !updateRequest.email) {
            this.submitted = false;
            return;
        }
        this.authService
            .updateProfile(updateRequest)
            .then(() => {
            this.submitted = false;
        })
            .catch((err) => {
            console.error(err);
            if (err.error.message === 'Username already exists!') {
                console.log('error');
                this.errors.push(this.translate.instant('errors.auth.profile.username_existence'));
                console.log(this.errors);
            }
            if (err.error.message === 'Email already exists!') {
                this.errors.push(this.translate.instant('errors.auth.profile.email_existence'));
            }
            this.submitted = false;
        });
        this.form.markAsPristine();
    }
    /**
     * Update password if changed
     * and confirmed
     */
    updatePassword() {
        this.clearErrors();
        this.passwordSubmitted = true;
        const updateRequest = {
            email: null,
            username: null,
            password: this.userObj.email && this.userObj.password_confirmation
                ? this.userObj.password
                : null,
            oldPassword: this.userObj.oldPassword
        };
        if (!updateRequest.password) {
            this.passwordSubmitted = false;
            return;
        }
        this.authService
            .updateProfile(updateRequest)
            .then(() => {
            this.passwordSubmitted = false;
            this.passwordForm.controls.password.reset();
            this.passwordForm.controls.rePass.reset();
            this.passwordForm.controls.oldPassword.reset();
        })
            .catch((err) => {
            console.error(err);
            // TODO: Display errors
            if (err.error.message === 'Old user password does not match!') {
                this.errors.push(this.translate.instant('errors.auth.profile.wrong_current_password'));
            }
            else if (err.error.message === 'Password does not fulfill requirements!') {
                this.errors.push(this.translate.instant('errors.auth.profile.password_requirements'));
            }
            else {
                this.errors.push(this.translate.instant('errors.auth.profile.password_change_error'));
            }
            this.passwordSubmitted = false;
        });
    }
    clearErrors() {
        this.errors = [];
    }
}
ProfileComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: ProfileComponent, deps: [{ token: AuthService }, { token: i3.TranslateService }], target: i0.ɵɵFactoryTarget.Component });
ProfileComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.1", type: ProfileComponent, selector: "strapi-auth-profile", ngImport: i0, template: "<h1 id=\"title\" class=\"title\">{{ 'auth.profile.title' | translate }}</h1>\n{{userObj | json}}\n\n<!-- <div class=\"row\">\n  <div class=\"col-lg-12\">\n    <nb-alert *ngIf=\"showMessages.error && errors?.length && !submitted\" outline=\"danger\" role=\"alert\">\n      <p class=\"alert-title\">\n        <b>{{ 'auth.profile.messages.error' | translate }}</b>\n      </p>\n      <ul class=\"alert-message-list\">\n        <li *ngFor=\"let error of errors\" class=\"alert-message\">{{ error }}</li>\n      </ul>\n    </nb-alert>\n\n    <nb-alert *ngIf=\"showMessages.success && messages?.length && !submitted\" outline=\"success\" role=\"alert\">\n      <p class=\"alert-title\">\n        <b>{{ 'auth.profile.messages.success' | translate }}</b>\n      </p>\n      <ul class=\"alert-message-list\">\n        <li *ngFor=\"let message of messages\" class=\"alert-message\">{{ message }}</li>\n      </ul>\n    </nb-alert>\n  </div>\n\n  <div class=\"col-lg-6\">\n    <nb-card>\n      <nb-card-header>\n        {{ 'auth.profile.general_information.title' | translate }}\n        <nb-icon class=\"float-right\" style=\"width: 2rem; height: 2rem;\"\n          *ngIf=\"oldUserObj.provider && iconPack.getIcon(oldUserObj?.provider + '-outline')\"\n          [icon]=\"oldUserObj?.provider + '-outline'\">\n        </nb-icon>\n      </nb-card-header>\n      <nb-card-body *ngIf=\"form\">\n        <form (ngSubmit)=\"update()\" [formGroup]=\"form\" aria-labelledby=\"title\">\n          <div class=\"form-control-group\">\n            <label class=\"label\" for=\"input-username\">\n              {{ 'auth.profile.form.input.username.label' | translate }}\n            </label>\n            <input nbInput [(ngModel)]=\"userObj.username\" #username formControlName=\"username\" id=\"input-username\"\n              name=\"username\" placeholder=\"{{ 'auth.profile.form.input.username.placeholder' | translate }}\" autofocus\n              fullWidth fieldSize=\"large\" [status]=\"\n                form.controls.username.dirty ? (form.controls.username.invalid ? 'danger' : 'success') : 'basic'\n              \" [required]=\"config.usernameRequired\" [minlength]=\"config.usernameMinLength\"\n              [maxlength]=\"config.usernameMaxLength\"\n              [readOnly]=\"oldUserObj.provider !== null && oldUserObj.provider !== 'local'\"\n              [attr.aria-invalid]=\"form.controls.username.invalid && form.controls.username.touched ? true : null\" />\n            <ng-container *ngIf=\"username.invalid && username.touched\">\n              <p class=\"caption status-danger\" *ngIf=\"form.controls.username.errors?.required\">\n                {{ 'auth.profile.form.input.username.required_message' | translate }}\n              </p>\n              <p class=\"caption status-danger\"\n                *ngIf=\"form.controls.username.errors?.minlength || form.controls.username.errors?.maxlength\">\n                {{\n                  'auth.profile.form.input.username.min_length_message'\n                    | translate: { min: config.usernameMinLength, max: config.usernameMaxLength }\n                }}\n              </p>\n            </ng-container>\n          </div>\n\n          <div class=\"form-control-group\">\n            <label class=\"label\" for=\"input-email\">\n              {{ 'auth.profile.form.input.email.label' | translate }}\n            </label>\n            <input nbInput [(ngModel)]=\"userObj.email\" #email formControlName=\"email\" id=\"input-email\" name=\"email\"\n              pattern=\".+@.+..+\" placeholder=\"{{ 'auth.profile.form.input.email.placeholder' | translate }}\" fullWidth\n              fieldSize=\"large\"\n              [status]=\"form.controls.email.dirty ? (form.controls.email.invalid ? 'danger' : 'success') : 'basic'\"\n              [readOnly]=\"(oldUserObj.provider !== null && oldUserObj.provider !== 'local')\"\n              [required]=\"config.emailRequired\"\n              [attr.aria-invalid]=\"form.controls.email.invalid && form.controls.email.touched ? true : null\" />\n            <ng-container *ngIf=\"form.controls.email.invalid && form.controls.email.touched\">\n              <p class=\"caption status-danger\" *ngIf=\"form.controls.email.errors?.required\">\n                {{ 'auth.profile.form.input.email.required_message' | translate }}\n              </p>\n              <p class=\"caption status-danger\" *ngIf=\"form.controls.email.errors?.pattern\">\n                {{ 'auth.profile.form.input.email.valid_message' | translate }}\n              </p>\n            </ng-container>\n          </div>\n\n          <br />\n\n          <button nbButton fullWidth status=\"primary\" size=\"large\"\n            [disabled]=\"submitted || !form.valid || (oldUserObj.provider !== null && oldUserObj.provider !== 'local')\"\n            [class.btn-pulse]=\"submitted\" [nbSpinner]=\"submitted\" [nbSpinnerStatus]=\"'control'\"\n            [nbSpinnerSize]=\"'medium'\">\n            {{ 'auth.profile.form.button.save' | translate }}\n          </button>\n        </form>\n      </nb-card-body>\n    </nb-card>\n  </div>\n\n  <div class=\"col-lg-6\" *ngIf=\"oldUserObj.provider === null || oldUserObj.provider === 'local'\">\n    <nb-card>\n      <nb-card-header> {{ 'auth.profile.change_password.title' | translate }}</nb-card-header>\n      <nb-card-body *ngIf=\"passwordForm\">\n        <form (ngSubmit)=\"updatePassword()\" [formGroup]=\"passwordForm\" aria-labelledby=\"title\">\n          <div class=\"form-control-group\">\n            <label class=\"label\" for=\"input-password\">\n              {{ 'auth.profile.form.input.oldPassword.label' | translate }}\n            </label>\n            <input nbInput [(ngModel)]=\"userObj.oldPassword\" #oldPassword formControlName=\"oldPassword\" type=\"password\"\n              id=\"input-oldPassword\" name=\"oldPassword\"\n              placeholder=\"{{ 'auth.profile.form.input.oldPassword.placeholder' | translate }}\" fullWidth\n              fieldSize=\"large\" [status]=\"\n                passwordForm.controls.oldPassword.dirty\n                  ? passwordForm.controls.oldPassword.invalid\n                    ? 'danger'\n                    : 'success'\n                  : 'basic'\n              \" [required]=\"config.passwordRequired\" [attr.aria-invalid]=\"\n                passwordForm.controls.oldPassword.invalid && passwordForm.controls.oldPassword.touched ? true : null\n              \" />\n            <ng-container\n              *ngIf=\"passwordForm.controls.oldPassword.invalid && passwordForm.controls.oldPassword.touched\">\n              <p class=\"caption status-danger\" *ngIf=\"passwordForm.controls.oldPassword.errors?.required\">\n                {{ 'auth.profile.form.input.oldPassword.required_message' | translate }}\n              </p>\n            </ng-container>\n          </div>\n\n          <div class=\"form-control-group\">\n            <label class=\"label\" for=\"input-password\">\n              {{ 'auth.profile.form.input.password.label' | translate }}\n            </label>\n            <input nbInput [(ngModel)]=\"userObj.password\" #password formControlName=\"password\" type=\"password\"\n              id=\"input-password\" name=\"password\"\n              placeholder=\"{{ 'auth.profile.form.input.password.placeholder' | translate }}\" fullWidth fieldSize=\"large\"\n              [status]=\"\n                passwordForm.controls.password.dirty\n                  ? passwordForm.controls.password.invalid\n                    ? 'danger'\n                    : 'success'\n                  : 'basic'\n              \" [required]=\"config.passwordRequired\" [minlength]=\"config.passwordMinLength\"\n              [maxlength]=\"config.passwordMaxLength\" [attr.aria-invalid]=\"\n                passwordForm.controls.password.invalid && passwordForm.controls.password.touched ? true : null\n              \" />\n            <ng-container *ngIf=\"passwordForm.controls.password.invalid && passwordForm.controls.password.touched\">\n              <p class=\"caption status-danger\" *ngIf=\"passwordForm.controls.password.errors?.required\">\n                {{ 'auth.profile.form.input.password.required_message' | translate }}\n              </p>\n              <p class=\"caption status-danger\" *ngIf=\"passwordForm.controls.password.errors?.pattern\">\n                {{ 'auth.profile.form.input.password.pattern_message' | translate }}\n              </p>\n              <p class=\"caption status-danger\" *ngIf=\"\n                  passwordForm.controls.password.errors?.minlength || passwordForm.controls.password.errors?.maxlength\n                \">\n                {{\n                  'auth.profile.form.input.password.min_length_message'\n                    | translate: { min: config.passwordMinLength, max: config.passwordMaxLength }\n                }}\n              </p>\n            </ng-container>\n          </div>\n\n          <div class=\"form-control-group\">\n            <label class=\"label\" for=\"input-re-password\">\n              {{ 'auth.profile.form.input.repeat_password.label' | translate }}</label>\n            <input nbInput [(ngModel)]=\"userObj.password_confirmation\" #rePass formControlName=\"rePass\" type=\"password\"\n              id=\"input-re-password\" name=\"rePass\"\n              placeholder=\"{{ 'auth.profile.form.input.repeat_password.placeholder' | translate }}\" fullWidth\n              fieldSize=\"large\" [status]=\"\n                passwordForm.controls.rePass.dirty\n                  ? passwordForm.controls.rePass.invalid ||\n                    passwordForm.controls.password.value != passwordForm.controls.rePass.value\n                    ? 'danger'\n                    : 'success'\n                  : 'basic'\n              \" [required]=\"config.passwordRequired\" [attr.aria-invalid]=\"\n                passwordForm.controls.rePass.invalid && passwordForm.controls.rePass.touched ? true : null\n              \" />\n            <ng-container *ngIf=\"passwordForm.controls.rePass.invalid && passwordForm.controls.rePass.touched\">\n              <p class=\"caption status-danger\" *ngIf=\"passwordForm.controls.rePass.errors?.required\">\n                {{ 'auth.profile.form.input.repeat_password.required_message' | translate }}\n              </p>\n              <p class=\"caption status-danger\" *ngIf=\"\n                  passwordForm.controls.password.value != passwordForm.controls.rePass.value &&\n                  !passwordForm.controls.rePass.errors?.required\n                \">\n                {{ 'auth.profile.form.input.repeat_password.match_message' | translate }}\n              </p>\n            </ng-container>\n          </div>\n\n          <br />\n\n          <button nbButton fullWidth status=\"primary\" size=\"large\"\n            [disabled]=\"passwordSubmitted || !passwordForm.valid || password.value !== rePass.value\"\n            [class.btn-pulse]=\"passwordSubmitted\" [nbSpinner]=\"passwordSubmitted\" [nbSpinnerStatus]=\"'control'\"\n            [nbSpinnerSize]=\"'medium'\">\n            {{ 'auth.profile.form.button.change_password' | translate }}\n          </button>\n        </form>\n      </nb-card-body>\n    </nb-card>\n  </div>\n</div> -->\n", styles: ["nb-card-body{overflow:visible;padding-top:0}nb-card-body>*{margin-top:1rem}.full-name-inputs,.validation-checkboxes{display:flex;margin:0 -.5rem}.full-name-inputs>*,.validation-checkboxes>*{margin:0 .5rem}.checkbox-radio{display:flex}.demo-items{flex:1 0 33%}\n"], pipes: { "translate": i3.TranslatePipe, "json": i3$1.JsonPipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: ProfileComponent, decorators: [{
            type: Component,
            args: [{ selector: 'strapi-auth-profile', template: "<h1 id=\"title\" class=\"title\">{{ 'auth.profile.title' | translate }}</h1>\n{{userObj | json}}\n\n<!-- <div class=\"row\">\n  <div class=\"col-lg-12\">\n    <nb-alert *ngIf=\"showMessages.error && errors?.length && !submitted\" outline=\"danger\" role=\"alert\">\n      <p class=\"alert-title\">\n        <b>{{ 'auth.profile.messages.error' | translate }}</b>\n      </p>\n      <ul class=\"alert-message-list\">\n        <li *ngFor=\"let error of errors\" class=\"alert-message\">{{ error }}</li>\n      </ul>\n    </nb-alert>\n\n    <nb-alert *ngIf=\"showMessages.success && messages?.length && !submitted\" outline=\"success\" role=\"alert\">\n      <p class=\"alert-title\">\n        <b>{{ 'auth.profile.messages.success' | translate }}</b>\n      </p>\n      <ul class=\"alert-message-list\">\n        <li *ngFor=\"let message of messages\" class=\"alert-message\">{{ message }}</li>\n      </ul>\n    </nb-alert>\n  </div>\n\n  <div class=\"col-lg-6\">\n    <nb-card>\n      <nb-card-header>\n        {{ 'auth.profile.general_information.title' | translate }}\n        <nb-icon class=\"float-right\" style=\"width: 2rem; height: 2rem;\"\n          *ngIf=\"oldUserObj.provider && iconPack.getIcon(oldUserObj?.provider + '-outline')\"\n          [icon]=\"oldUserObj?.provider + '-outline'\">\n        </nb-icon>\n      </nb-card-header>\n      <nb-card-body *ngIf=\"form\">\n        <form (ngSubmit)=\"update()\" [formGroup]=\"form\" aria-labelledby=\"title\">\n          <div class=\"form-control-group\">\n            <label class=\"label\" for=\"input-username\">\n              {{ 'auth.profile.form.input.username.label' | translate }}\n            </label>\n            <input nbInput [(ngModel)]=\"userObj.username\" #username formControlName=\"username\" id=\"input-username\"\n              name=\"username\" placeholder=\"{{ 'auth.profile.form.input.username.placeholder' | translate }}\" autofocus\n              fullWidth fieldSize=\"large\" [status]=\"\n                form.controls.username.dirty ? (form.controls.username.invalid ? 'danger' : 'success') : 'basic'\n              \" [required]=\"config.usernameRequired\" [minlength]=\"config.usernameMinLength\"\n              [maxlength]=\"config.usernameMaxLength\"\n              [readOnly]=\"oldUserObj.provider !== null && oldUserObj.provider !== 'local'\"\n              [attr.aria-invalid]=\"form.controls.username.invalid && form.controls.username.touched ? true : null\" />\n            <ng-container *ngIf=\"username.invalid && username.touched\">\n              <p class=\"caption status-danger\" *ngIf=\"form.controls.username.errors?.required\">\n                {{ 'auth.profile.form.input.username.required_message' | translate }}\n              </p>\n              <p class=\"caption status-danger\"\n                *ngIf=\"form.controls.username.errors?.minlength || form.controls.username.errors?.maxlength\">\n                {{\n                  'auth.profile.form.input.username.min_length_message'\n                    | translate: { min: config.usernameMinLength, max: config.usernameMaxLength }\n                }}\n              </p>\n            </ng-container>\n          </div>\n\n          <div class=\"form-control-group\">\n            <label class=\"label\" for=\"input-email\">\n              {{ 'auth.profile.form.input.email.label' | translate }}\n            </label>\n            <input nbInput [(ngModel)]=\"userObj.email\" #email formControlName=\"email\" id=\"input-email\" name=\"email\"\n              pattern=\".+@.+..+\" placeholder=\"{{ 'auth.profile.form.input.email.placeholder' | translate }}\" fullWidth\n              fieldSize=\"large\"\n              [status]=\"form.controls.email.dirty ? (form.controls.email.invalid ? 'danger' : 'success') : 'basic'\"\n              [readOnly]=\"(oldUserObj.provider !== null && oldUserObj.provider !== 'local')\"\n              [required]=\"config.emailRequired\"\n              [attr.aria-invalid]=\"form.controls.email.invalid && form.controls.email.touched ? true : null\" />\n            <ng-container *ngIf=\"form.controls.email.invalid && form.controls.email.touched\">\n              <p class=\"caption status-danger\" *ngIf=\"form.controls.email.errors?.required\">\n                {{ 'auth.profile.form.input.email.required_message' | translate }}\n              </p>\n              <p class=\"caption status-danger\" *ngIf=\"form.controls.email.errors?.pattern\">\n                {{ 'auth.profile.form.input.email.valid_message' | translate }}\n              </p>\n            </ng-container>\n          </div>\n\n          <br />\n\n          <button nbButton fullWidth status=\"primary\" size=\"large\"\n            [disabled]=\"submitted || !form.valid || (oldUserObj.provider !== null && oldUserObj.provider !== 'local')\"\n            [class.btn-pulse]=\"submitted\" [nbSpinner]=\"submitted\" [nbSpinnerStatus]=\"'control'\"\n            [nbSpinnerSize]=\"'medium'\">\n            {{ 'auth.profile.form.button.save' | translate }}\n          </button>\n        </form>\n      </nb-card-body>\n    </nb-card>\n  </div>\n\n  <div class=\"col-lg-6\" *ngIf=\"oldUserObj.provider === null || oldUserObj.provider === 'local'\">\n    <nb-card>\n      <nb-card-header> {{ 'auth.profile.change_password.title' | translate }}</nb-card-header>\n      <nb-card-body *ngIf=\"passwordForm\">\n        <form (ngSubmit)=\"updatePassword()\" [formGroup]=\"passwordForm\" aria-labelledby=\"title\">\n          <div class=\"form-control-group\">\n            <label class=\"label\" for=\"input-password\">\n              {{ 'auth.profile.form.input.oldPassword.label' | translate }}\n            </label>\n            <input nbInput [(ngModel)]=\"userObj.oldPassword\" #oldPassword formControlName=\"oldPassword\" type=\"password\"\n              id=\"input-oldPassword\" name=\"oldPassword\"\n              placeholder=\"{{ 'auth.profile.form.input.oldPassword.placeholder' | translate }}\" fullWidth\n              fieldSize=\"large\" [status]=\"\n                passwordForm.controls.oldPassword.dirty\n                  ? passwordForm.controls.oldPassword.invalid\n                    ? 'danger'\n                    : 'success'\n                  : 'basic'\n              \" [required]=\"config.passwordRequired\" [attr.aria-invalid]=\"\n                passwordForm.controls.oldPassword.invalid && passwordForm.controls.oldPassword.touched ? true : null\n              \" />\n            <ng-container\n              *ngIf=\"passwordForm.controls.oldPassword.invalid && passwordForm.controls.oldPassword.touched\">\n              <p class=\"caption status-danger\" *ngIf=\"passwordForm.controls.oldPassword.errors?.required\">\n                {{ 'auth.profile.form.input.oldPassword.required_message' | translate }}\n              </p>\n            </ng-container>\n          </div>\n\n          <div class=\"form-control-group\">\n            <label class=\"label\" for=\"input-password\">\n              {{ 'auth.profile.form.input.password.label' | translate }}\n            </label>\n            <input nbInput [(ngModel)]=\"userObj.password\" #password formControlName=\"password\" type=\"password\"\n              id=\"input-password\" name=\"password\"\n              placeholder=\"{{ 'auth.profile.form.input.password.placeholder' | translate }}\" fullWidth fieldSize=\"large\"\n              [status]=\"\n                passwordForm.controls.password.dirty\n                  ? passwordForm.controls.password.invalid\n                    ? 'danger'\n                    : 'success'\n                  : 'basic'\n              \" [required]=\"config.passwordRequired\" [minlength]=\"config.passwordMinLength\"\n              [maxlength]=\"config.passwordMaxLength\" [attr.aria-invalid]=\"\n                passwordForm.controls.password.invalid && passwordForm.controls.password.touched ? true : null\n              \" />\n            <ng-container *ngIf=\"passwordForm.controls.password.invalid && passwordForm.controls.password.touched\">\n              <p class=\"caption status-danger\" *ngIf=\"passwordForm.controls.password.errors?.required\">\n                {{ 'auth.profile.form.input.password.required_message' | translate }}\n              </p>\n              <p class=\"caption status-danger\" *ngIf=\"passwordForm.controls.password.errors?.pattern\">\n                {{ 'auth.profile.form.input.password.pattern_message' | translate }}\n              </p>\n              <p class=\"caption status-danger\" *ngIf=\"\n                  passwordForm.controls.password.errors?.minlength || passwordForm.controls.password.errors?.maxlength\n                \">\n                {{\n                  'auth.profile.form.input.password.min_length_message'\n                    | translate: { min: config.passwordMinLength, max: config.passwordMaxLength }\n                }}\n              </p>\n            </ng-container>\n          </div>\n\n          <div class=\"form-control-group\">\n            <label class=\"label\" for=\"input-re-password\">\n              {{ 'auth.profile.form.input.repeat_password.label' | translate }}</label>\n            <input nbInput [(ngModel)]=\"userObj.password_confirmation\" #rePass formControlName=\"rePass\" type=\"password\"\n              id=\"input-re-password\" name=\"rePass\"\n              placeholder=\"{{ 'auth.profile.form.input.repeat_password.placeholder' | translate }}\" fullWidth\n              fieldSize=\"large\" [status]=\"\n                passwordForm.controls.rePass.dirty\n                  ? passwordForm.controls.rePass.invalid ||\n                    passwordForm.controls.password.value != passwordForm.controls.rePass.value\n                    ? 'danger'\n                    : 'success'\n                  : 'basic'\n              \" [required]=\"config.passwordRequired\" [attr.aria-invalid]=\"\n                passwordForm.controls.rePass.invalid && passwordForm.controls.rePass.touched ? true : null\n              \" />\n            <ng-container *ngIf=\"passwordForm.controls.rePass.invalid && passwordForm.controls.rePass.touched\">\n              <p class=\"caption status-danger\" *ngIf=\"passwordForm.controls.rePass.errors?.required\">\n                {{ 'auth.profile.form.input.repeat_password.required_message' | translate }}\n              </p>\n              <p class=\"caption status-danger\" *ngIf=\"\n                  passwordForm.controls.password.value != passwordForm.controls.rePass.value &&\n                  !passwordForm.controls.rePass.errors?.required\n                \">\n                {{ 'auth.profile.form.input.repeat_password.match_message' | translate }}\n              </p>\n            </ng-container>\n          </div>\n\n          <br />\n\n          <button nbButton fullWidth status=\"primary\" size=\"large\"\n            [disabled]=\"passwordSubmitted || !passwordForm.valid || password.value !== rePass.value\"\n            [class.btn-pulse]=\"passwordSubmitted\" [nbSpinner]=\"passwordSubmitted\" [nbSpinnerStatus]=\"'control'\"\n            [nbSpinnerSize]=\"'medium'\">\n            {{ 'auth.profile.form.button.change_password' | translate }}\n          </button>\n        </form>\n      </nb-card-body>\n    </nb-card>\n  </div>\n</div> -->\n", styles: ["nb-card-body{overflow:visible;padding-top:0}nb-card-body>*{margin-top:1rem}.full-name-inputs,.validation-checkboxes{display:flex;margin:0 -.5rem}.full-name-inputs>*,.validation-checkboxes>*{margin:0 .5rem}.checkbox-radio{display:flex}.demo-items{flex:1 0 33%}\n"] }]
        }], ctorParameters: function () { return [{ type: AuthService }, { type: i3.TranslateService }]; } });

class AuthInterceptor {
    constructor(injector, router, strapiAuthConfig) {
        this.injector = injector;
        this.router = router;
        this.strapiAuthConfig = strapiAuthConfig;
        this.AUTH_HEADER = 'Authorization';
    }
    intercept(req, next) {
        this.authService = this.injector.get(AuthService);
        this.tokenService = this.injector.get(TokenService);
        this.token = this.tokenService.getToken();
        if (!req.headers.has('Content-Type')) {
            req = req.clone({
                headers: req.headers.set('Content-Type', 'application/json')
            });
        }
        req = this.addAuthenticationToken(req);
        return next.handle(req).pipe(catchError((error) => {
            const authError = error.error;
            switch (error.status) {
                // Intercept unauthorized request
                case 401:
                    // Check if error response is caused by invalid token
                    if (authError.error.name === 'UnauthorizedError') {
                        return this.authService.logout().then(() => {
                            this.router.navigateByUrl('/auth/login');
                        });
                    }
                    else {
                        return throwError(() => error);
                    }
                case 403:
                    return throwError(() => error);
                case 404:
                    return throwError(() => error);
                default:
                    return throwError(() => error);
            }
        }));
    }
    addAuthenticationToken(request) {
        // If we do not have a token yet then we should not set the header.
        // Here we could first retrieve the token from where we store it.
        if (!this.token) {
            return request;
        }
        // If you are calling an outside domain then do not add the token.
        if (!request.url.match(this.strapiAuthConfig.strapi_base_url)) {
            return request;
        }
        return request.clone({
            headers: request.headers.set(this.AUTH_HEADER, 'Bearer ' + this.token)
        });
    }
}
AuthInterceptor.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: AuthInterceptor, deps: [{ token: i0.Injector }, { token: i1$1.Router }, { token: ConfigServiceInjector }], target: i0.ɵɵFactoryTarget.Injectable });
AuthInterceptor.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: AuthInterceptor });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: AuthInterceptor, decorators: [{
            type: Injectable
        }], ctorParameters: function () {
        return [{ type: i0.Injector }, { type: i1$1.Router }, { type: undefined, decorators: [{
                        type: Inject,
                        args: [ConfigServiceInjector]
                    }] }];
    } });

var errors$1 = {
    auth: {
        login: {
            password_or_email: "Passwort oder Email Adresse sind möglicherweise falsch!",
            "undefined": "Es ist ein unbekannter Fehler aufgetreten!",
            email_verification: "Die Email muss zuvor bestätigt werden! Bitte überprüfen Sie ihr Mail Postfach.",
            account_blocked: "Ihr Account wurde geblockt! Eine Anmeldung ist deshalb nicht möglich."
        },
        register: {
            password_or_email: "Email oder Username sind möglicherweise schon vergeben!",
            "undefined": "Es ist ein unbekannter Fehler aufgetreten!"
        },
        "request-password": {
            email: "Zu dieser Email Adresse gehört kein Account!",
            "undefined": "Es ist ein unbekannter Fehler aufgetreten!"
        },
        "reset-password": {
            code: "Code zur Wiederherstellung ist abgelaufen oder ungültig!",
            "undefined": "Es ist ein unbekannter Fehler aufgetreten!"
        },
        profile: {
            username_existence: "Der Benutzername existiert bereits!",
            email_existence: "Die Email existiert bereits!",
            wrong_current_password: "Das eingegebene aktuelle Passwort ist falsch!",
            password_requirements: "Das Passwort entspricht nicht der Passwortrichtlinie!",
            password_change_error: "Das Passwort konnte nicht geändert werden!"
        }
    }
};
var auth$1 = {
    change_password: {
        form: {
            button: {
                back_to: {
                    text: "Zurück zum Login",
                    title: "Registrieren"
                },
                change_password: {
                    title: "Password Ändern"
                }
            },
            input: {
                password: {
                    label: "Neues Passwort:",
                    min_length_message: "Das Passwort sollte zwischen {{min}} und {{max}} Zeichen enthalten.",
                    placeholder: "Neues Passwort",
                    required_message: "Ein Passwort wird benötigt!"
                },
                password_confirmation: {
                    label: "Passwort Wiederholen:",
                    match_message: "Die Passwörter stimmen nicht überein!",
                    placeholder: "Passwort Wiederholen",
                    required_message: "Eine Bestätigung des Passwortes wird benötigt!"
                }
            }
        },
        messages: {
            error: "Es ist ein Fehler aufgetreten!",
            success: "Passwort wurde erfolgreich geändert."
        },
        subtitle: "Bitte gib dein neues Passwort ein.",
        title: "Password Ändern"
    },
    login: {
        form: {
            button: {
                login: "Einloggen",
                register: {
                    label: "Hast du noch keinen Account?",
                    link: "Registrieren"
                },
                login_with: "Einloggen mit"
            },
            input: {
                email: {
                    label: "Email Adresse:",
                    placeholder: "Email Adresse",
                    required_message: "Eine Email Adresse wird benötigt!",
                    valid_message: "Diese Email Adresse ist nicht valide!"
                },
                password: {
                    forgot_message: "Passwort vergessen?",
                    label: "Passwort:",
                    min_length_message: "Das Passwort sollte zwischen {{min}} und {{max}} Zeichen enthalten.",
                    placeholder: "Passwort",
                    required_message: "Ein Passwort wird benötigt!"
                }
            }
        },
        messages: {
            error: "Es ist ein Fehler aufgetreten!",
            success: "Erfolgreich angemeldet!"
        },
        subtitle: "Hallo! Bitte melde dich mit deiner Email an.",
        title: "Login"
    },
    logout: {
        logout_text: "Du wirst abgemeldet, bitte warten ..."
    },
    register: {
        form: {
            button: {
                existing_account: {
                    text: "Hast du schon einen Account?",
                    title: "Anmelden"
                },
                register: {
                    title: "Registrieren"
                }
            },
            input: {
                email: {
                    label: "Email Adresse:",
                    placeholder: "Email Adresse",
                    required_message: "Eine Email Adresse wird benötigt!",
                    valid_message: "Diese Email Adresse ist nicht valide!"
                },
                firstname: {
                    label: "Vorname:",
                    min_length_message: "Der Vorname sollte zwischen {{min}} und {{max}} Zeichen enthalten.",
                    placeholder: "Vorname",
                    required_message: "Ein Vorname wird benötigt!"
                },
                lastname: {
                    label: "Nachname:",
                    min_length_message: "Der Nachname sollte zwischen {{min}} und {{max}} Zeichen enthalten.",
                    placeholder: "Nachname",
                    required_message: "Ein Nachname wird benötigt!"
                },
                password: {
                    label: "Passwort:",
                    min_length_message: "Das Passwort sollte zwischen {{min}} und {{max}} Zeichen enthalten.",
                    placeholder: "Passwort",
                    required_message: "Ein Passwort wird benötigt!",
                    pattern_message: "Das Passwort muss mindestens ein Sonderzeichen, Groß- und Kleinbuchstaben sowie eine Zahl enthalten."
                },
                repeat_password: {
                    label: "Passwort bestätigen:",
                    match_message: "Beide Passwörter müssen übereinstimmen!",
                    placeholder: "Passwort bestätigen",
                    required_message: "Eine Passwort Bestätigten wird benötigt!"
                },
                username: {
                    label: "Username:",
                    min_length_message: "Der Username sollte zwischen {{min}} und {{max}} Zeichen enthalten.",
                    placeholder: "Username",
                    required_message: "Ein Username wird benötigt!"
                }
            }
        },
        messages: {
            error: "Es ist ein Fehler aufgetreten!",
            success: "Erfolgreich registriert!"
        },
        title: "Registrieren"
    },
    request_password: {
        form: {
            button: {
                back_to: {
                    text: "Zurück zum Login",
                    title: "Registrieren"
                },
                request: {
                    title: "Zurücksetzen"
                }
            },
            input: {
                email: {
                    label: "Gib hier deine Email Adresse ein:",
                    placeholder: "Email Adresse",
                    required_message: "Eine Email Adresse wird benötigt!",
                    valid_message: "Diese Email Adresse ist nicht valide!"
                }
            }
        },
        messages: {
            error: "Es ist ein Fehler aufgetreten!",
            success: "Erfolgreich verschickt."
        },
        subtitle: "Gib hier deine Email Adresse an und wir senden dir einen Link um dein Passwort zurückzusetzen.",
        title: "Passwort Zurücksetzen"
    },
    restore: {
        form: {
            button: {
                register: {
                    label: "Hast du noch keinen Account?",
                    link: "Registrieren"
                },
                restore: "Wiederherrstellen"
            },
            input: {
                email: {
                    label: "Email Adresse:",
                    placeholder: "Email Adresse",
                    required_message: "Eine Email Adresse wird benötigt!",
                    valid_message: "Diese Email Adresse ist nicht valide!"
                },
                password: {
                    forgot_message: "Passwort vergessen?",
                    label: "Passwort:",
                    min_length_message: "Das Passwort sollte zwischen {{min}} und {{max}} Zeichen enthalten.",
                    placeholder: "Passwort",
                    required_message: "Ein Passwort wird benötigt!"
                }
            }
        },
        messages: {
            error: "Es ist ein Fehler aufgetreten!",
            success: "Erfolgreich wiederherrgestellt!"
        },
        subtitle: "Hallo! Hier kannst du deinen Account mit deiner Email wiederherrstellen.",
        title: "Wiederherrstellung"
    },
    profile: {
        change_password: {
            title: "Passwort ändern"
        },
        form: {
            button: {
                change_password: "Password ändern",
                save: "Speichern"
            },
            input: {
                email: {
                    label: "Email Adresse:",
                    placeholder: "Email Adresse",
                    required_message: "Eine Email Adresse wird benötigt!",
                    valid_message: "Diese Email Adresse ist nicht valide!"
                },
                firstname: {
                    label: "Vorname:",
                    min_length_message: "Der Vorname sollte zwischen {{min}} und {{max}} Zeichen enthalten.",
                    placeholder: "Vorname",
                    required_message: "Ein Vorname wird benötigt!"
                },
                lastname: {
                    label: "Nachname:",
                    min_length_message: "Der Nachname sollte zwischen {{min}} und {{max}} Zeichen enthalten.",
                    placeholder: "Nachname",
                    required_message: "Ein Nachname wird benötigt!"
                },
                password: {
                    label: "Passwort:",
                    min_length_message: "Das Passwort sollte zwischen {{min}} und {{max}} Zeichen enthalten.",
                    placeholder: "Passwort",
                    required_message: "Ein Passwort wird benötigt!",
                    pattern_message: "Das Passwort muss mindestens ein Sonderzeichen, Groß- und Kleinbuchstaben sowie eine Zahl enthalten."
                },
                repeat_password: {
                    label: "Passwort bestätigen:",
                    match_message: "Beide Passwörter müssen übereinstimmen!",
                    placeholder: "Passwort bestätigen",
                    required_message: "Eine Passwort Bestätigten wird benötigt!"
                },
                username: {
                    label: "Username:",
                    min_length_message: "Der Username sollte zwischen {{min}} und {{max}} Zeichen enthalten.",
                    placeholder: "Username",
                    required_message: "Ein Username wird benötigt!"
                },
                oldPassword: {
                    label: "Aktuelles Passwort:",
                    placeholder: "Aktuelles Passwort",
                    required_message: "Es wird das aktuelle Passwort benötigt!"
                }
            }
        },
        general_information: {
            title: "Allgemeine Informationen"
        },
        messages: {
            error: "Es ist ein Fehler aufgetreten!",
            success: "Erfolgreich registriert!"
        },
        title: "Profil"
    }
};
var deLang = {
    errors: errors$1,
    auth: auth$1
};

var errors = {
    auth: {
        login: {
            password_or_email: "Password or email address may be wrong!",
            "undefined": "An unknown error has occurred!",
            email_verification: "The email must be confirmed before! Please check your mailbox.",
            account_blocked: "Your account has been blocked! Therefore, registration is not possible."
        },
        register: {
            password_or_email: "Email or username are possibly already taken!",
            "undefined": "An unknown error has occurred!"
        },
        "request-password": {
            email: "No account belongs to this email address!",
            "undefined": "An unknown error has occurred!"
        },
        "reset-password": {
            code: "Recovery code has expired or is invalid!",
            "undefined": "An unknown error has occurred!"
        },
        profile: {
            username_existence: "Username already exists!",
            email_existence: "Email already exists!",
            wrong_current_password: "The given current password does not match!",
            password_requirements: "Password does not fulfill requirements!",
            password_change_error: "Password could not be changed!"
        }
    }
};
var auth = {
    change_password: {
        form: {
            button: {
                back_to: {
                    text: "Back to Log In",
                    title: "Register"
                },
                change_password: {
                    title: "Change password"
                }
            },
            input: {
                password: {
                    label: "New Password:",
                    min_length_message: "Password should contain from {{min}} to {{max}} characters",
                    placeholder: "New Password",
                    required_message: "Password is required!"
                },
                password_confirmation: {
                    label: "Confirm Password:",
                    match_message: "Password does not match the confirm password.",
                    placeholder: "Confirm Password",
                    required_message: "Password confirmation is required!"
                }
            }
        },
        messages: {
            error: "Oh snap!",
            success: "Hooray!"
        },
        subtitle: "Please set a new password",
        title: "Change password"
    },
    login: {
        form: {
            button: {
                login: "Log In",
                register: {
                    label: "Don't have an account?",
                    link: "Register"
                },
                login_with: "Log In with"
            },
            input: {
                email: {
                    label: "Email address:",
                    placeholder: "Email address",
                    required_message: "Email is required!",
                    valid_message: "Email should be the real one!"
                },
                password: {
                    forgot_message: "Forgot Password?",
                    label: "Password:",
                    min_length_message: "Password should contain from {{min}} to {{max}} characters",
                    placeholder: "Password",
                    required_message: "Password is required!"
                }
            }
        },
        messages: {
            error: "Oh snap!",
            success: "Hooray!"
        },
        subtitle: "Hello! Log in with your email.",
        title: "Login"
    },
    logout: {
        logout_text: "Logging out, please wait..."
    },
    register: {
        form: {
            button: {
                existing_account: {
                    text: "Already have an account?",
                    title: "Log in"
                },
                register: {
                    title: "Register"
                }
            },
            input: {
                email: {
                    label: "Email address:",
                    placeholder: "Email address",
                    required_message: "Email is required!",
                    valid_message: "Email should be the real one!"
                },
                firstname: {
                    label: "Firstname:",
                    min_length_message: "Firstname should contains from {{min}} to {{max}} characters",
                    placeholder: "Firstname",
                    required_message: "Firstname is required!"
                },
                lastname: {
                    label: "Lastname:",
                    min_length_message: "Lastname should contains from {{min}} to {{max}} characters",
                    placeholder: "Lastname",
                    required_message: "Lastname is required!"
                },
                password: {
                    label: "Password:",
                    min_length_message: "Password should contain from {{min}} to {{max}} characters",
                    placeholder: "Password",
                    required_message: "Password is required!",
                    pattern_message: "The password must contain at least one special character, upper and lower case letters and a number."
                },
                repeat_password: {
                    label: "Repeat password:",
                    match_message: "Password confirmation is required!",
                    placeholder: "Repeat password",
                    required_message: "Password confirmation is required!"
                },
                username: {
                    label: "Username:",
                    min_length_message: "Username should contain from {{min}} to {{max}} characters",
                    placeholder: "Username",
                    required_message: "Username is required!"
                }
            }
        },
        messages: {
            error: "Oh snap!",
            success: "Hooray!"
        },
        title: "Register"
    },
    request_password: {
        form: {
            button: {
                back_to: {
                    text: "Back to Log In",
                    title: "Register"
                },
                request: {
                    title: "Request password"
                }
            },
            input: {
                email: {
                    label: "Enter your email address:",
                    placeholder: "Email address",
                    required_message: "Email is required!",
                    valid_message: "Email should be the real one!"
                }
            }
        },
        messages: {
            error: "Oh snap!",
            success: "Hooray!"
        },
        subtitle: "Enter your email address and we’ll send a link to reset your password",
        title: "Forgot Password"
    },
    restore: {
        form: {
            button: {
                register: {
                    label: "Don't have an account?",
                    link: "Register"
                },
                restore: "Restore Account"
            },
            input: {
                email: {
                    label: "Email address:",
                    placeholder: "Email address",
                    required_message: "Email is required!",
                    valid_message: "Email should be the real one!"
                },
                password: {
                    forgot_message: "Forgot Password?",
                    label: "Password:",
                    min_length_message: "Password should contain from {{min}} to {{max}} characters",
                    placeholder: "Password",
                    required_message: "Password is required!"
                }
            }
        },
        messages: {
            error: "Oh snap!",
            success: "Successfully restored account!"
        },
        subtitle: "Hello! Restore account with your email.",
        title: "Restore"
    },
    profile: {
        change_password: {
            title: "Change password"
        },
        form: {
            button: {
                change_password: "Change password",
                save: "Save"
            },
            input: {
                email: {
                    label: "Email address:",
                    placeholder: "Email address",
                    required_message: "Email is required!",
                    valid_message: "Email should be the real one!"
                },
                firstname: {
                    label: "Firstname:",
                    min_length_message: "Firstname should contains from {{min}} to {{max}} characters",
                    placeholder: "Firstname",
                    required_message: "Firstname is required!"
                },
                lastname: {
                    label: "Lastname:",
                    min_length_message: "Lastname should contains from {{min}} to {{max}} characters",
                    placeholder: "Lastname",
                    required_message: "Lastname is required!"
                },
                password: {
                    label: "Password:",
                    min_length_message: "Password should contain from {{min}} to {{max}} characters",
                    placeholder: "Password",
                    required_message: "Password is required!",
                    pattern_message: "The password must contain at least one special character, upper and lower case letters and a number."
                },
                repeat_password: {
                    label: "Repeat password:",
                    match_message: "Password confirmation is required!",
                    placeholder: "Repeat password",
                    required_message: "Password confirmation is required!"
                },
                username: {
                    label: "Username:",
                    min_length_message: "Username should contain from {{min}} to {{max}} characters",
                    placeholder: "Username",
                    required_message: "Username is required!"
                },
                oldPassword: {
                    label: "Current password:",
                    placeholder: "Current password",
                    required_message: "Current password is required!"
                }
            }
        },
        general_information: {
            title: "General informations"
        },
        messages: {
            error: "Oh snap!",
            success: "Hooray!"
        },
        title: "Profile"
    }
};
var enLang = {
    errors: errors,
    auth: auth
};

class LanguageService {
    constructor() { }
    // TODO: Rewrite language service and accept ngx-translate or custom language config object for translations
    // TODO: Store registered languages
    /**
     * Set default translation for StrapiAuthModule
     */
    setDefaultTranslation(translate) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.loadTranslationFiles(translate);
            const defaultLang = this.getDefaultLanguage(translate);
            translate.setDefaultLang(defaultLang);
        });
    }
    /**
     * Load translation files
     * @param translate
     */
    loadTranslationFiles(translate) {
        return __awaiter(this, void 0, void 0, function* () {
            // TODO: decrease loading time && load only specified languages
            // Currently all files are loaded
            yield lastValueFrom(translate.getTranslation('en')).then(() => {
                translate.setTranslation('en', enLang, true);
            });
            yield lastValueFrom(translate.getTranslation('de')).then(() => {
                translate.setTranslation('de', deLang, true);
            });
        });
    }
    /**
     * Get default language
     * @param translate
     * @returns string
     */
    getDefaultLanguage(translate) {
        const defaultLang = translate.getDefaultLang();
        return defaultLang || 'en';
    }
}
LanguageService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: LanguageService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
LanguageService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: LanguageService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: LanguageService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class ValidationComponent {
    constructor() { }
    ngOnInit() { }
}
ValidationComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: ValidationComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
ValidationComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.1", type: ValidationComponent, selector: "strapi-validation", ngImport: i0, template: "<p>validation works!</p>\n", styles: [""] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: ValidationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'strapi-validation', template: "<p>validation works!</p>\n", styles: [""] }]
        }], ctorParameters: function () { return []; } });

var AuthComponents;
(function (AuthComponents) {
    AuthComponents["Login"] = "login";
    AuthComponents["Logout"] = "logout";
    AuthComponents["Register"] = "register";
    AuthComponents["RequestPassword"] = "request-password";
    AuthComponents["ResetPassword"] = "reset-password";
})(AuthComponents || (AuthComponents = {}));
var AuthComponents$1 = AuthComponents;

class LoginBaseComponent {
    constructor(authService, router, translate, strapiAuthConfig) {
        this.authService = authService;
        this.router = router;
        this.translate = translate;
        this.strapiAuthConfig = strapiAuthConfig;
        this.formGroup = new FormGroup({
            identifier: new FormControl('', [Validators.required, Validators.email]),
            password: new FormControl('', [Validators.required])
        });
    }
    ngOnInit() {
        if (this.authService.isAuthenticated) {
            this.router.navigateByUrl(this.authService.LoginRedirectUrl);
        }
    }
    /**
     * Login for local registered users
     */
    login() {
        this.loginReq = {
            identifier: this.formGroup.get('identifier').value,
            password: this.formGroup.get('password').value
        };
        this.authService
            .login(this.loginReq)
            .then(() => {
            if (this.authService.isAuthenticated) {
                this.router.navigateByUrl(this.authService.LoginRedirectUrl);
            }
        })
            .catch((err) => {
            const loginError = err.error;
            console.log(loginError.error.message);
        });
        // this.errors = [];
        // this.messages = [];
        // this.submitted = true;
        // this.authService
        //   .login(this.authLoginReq.email, this.authLoginReq.password)
        //   .then(() => {
        //     this.submitted = false;
        //     if (this.authService.isAuthenticated) {
        //       this.router.navigateByUrl(this.authService.LoginRedirectUrl);
        //     }
        //   })
        //   .catch((err: HttpErrorResponse) => {
        //     this.submitted = false;
        //     console.log(err);
        //     if (err.status === 400) {
        //       switch (err.error.data[0].messages[0].id) {
        //         // Check if email is confirmed
        //         case 'Auth.form.error.confirmed':
        //           this.errors.push(
        //             this.translate.instant('errors.auth.login.email_verification')
        //           );
        //           break;
        //         // Check if user has been blocked
        //         case 'Auth.form.error.blocked':
        //           this.errors.push(
        //             this.translate.instant('errors.auth.login.account_blocked')
        //           );
        //           break;
        //         default:
        //           this.errors.push(
        //             this.translate.instant('errors.auth.login.password_or_email')
        //           );
        //           break;
        //       }
        //     } else {
        //       this.errors.push(
        //         this.translate.instant('errors.auth.login.undefined')
        //       );
        //     }
        //   });
    }
    /**
     * Login using third party provider
     */
    loginProvider(provider) {
        window.location.href =
            this.authService.strapiAuthConfig.strapi_base_url +
                '/connect/' +
                provider;
    }
}
LoginBaseComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: LoginBaseComponent, deps: [{ token: AuthService }, { token: i1$1.Router }, { token: i3.TranslateService }, { token: ConfigServiceInjector }], target: i0.ɵɵFactoryTarget.Component });
LoginBaseComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.1", type: LoginBaseComponent, selector: "strapi-login-base", ngImport: i0, template: '', isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: LoginBaseComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'strapi-login-base',
                    template: ''
                }]
        }], ctorParameters: function () {
        return [{ type: AuthService }, { type: i1$1.Router }, { type: i3.TranslateService }, { type: undefined, decorators: [{
                        type: Inject,
                        args: [ConfigServiceInjector]
                    }] }];
    } });

class DefaultLoginComponent extends LoginBaseComponent {
    constructor(authService, router, translate, strapiAuthConfig) {
        super(authService, router, translate, strapiAuthConfig);
        this.authService = authService;
        this.router = router;
        this.translate = translate;
        this.strapiAuthConfig = strapiAuthConfig;
    }
}
DefaultLoginComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: DefaultLoginComponent, deps: [{ token: AuthService }, { token: i1$1.Router }, { token: i3.TranslateService }, { token: ConfigServiceInjector }], target: i0.ɵɵFactoryTarget.Component });
DefaultLoginComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.1", type: DefaultLoginComponent, selector: "strapi-default-login", usesInheritance: true, ngImport: i0, template: "<h1>{{ 'auth.login.title' | translate }}</h1>\n<p>{{ 'auth.login.subtitle' | translate }}</p>\n\n<form [formGroup]=\"formGroup\">\n\n  <div class=\"form-group\">\n    <label class=\"label\" for=\"input-email\">{{ 'auth.login.form.input.email.label' | translate }}</label>\n    <input type=\"email\" class=\"form-control\" id=\"email\" formControlName=\"identifier\"\n      placeholder=\"{{ 'auth.login.form.input.email.placeholder' | translate }}\" />\n  </div>\n\n  <div class=\"form-group\">\n    <label class=\"label\" for=\"input-password\">{{ 'auth.login.form.input.password.label' | translate }}</label>\n    <input type=\"password\" class=\"form-control\" id=\"password\" formControlName=\"password\"\n      placeholder=\"{{ 'auth.login.form.input.password.placeholder' | translate }}\" />\n  </div>\n\n  <div class=\"mt-2\">\n    <button type=\"submit\" class=\"btn btn-primary\" (click)=\"login()\" [disabled]=\"!formGroup.valid\">\n      {{ 'auth.login.form.button.login' | translate }}\n    </button>\n  </div>\n\n  <section class=\"mt-2\" aria-label=\"Register\">\n    {{ 'auth.login.form.button.register.label' | translate }}\n    <a class=\"text-link\" routerLink=\"../register\">\n      {{ 'auth.login.form.button.register.link' | translate }}\n    </a>\n  </section>\n</form>\n\n<!-- <h1 id=\"title\" class=\"title\">{{ 'auth.login.title' | translate }}</h1>\n<p class=\"sub-title\">{{ 'auth.login.subtitle' | translate }}</p>\n\n<nb-alert *ngIf=\"showMessages.error && errors?.length && !submitted\" outline=\"danger\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.login.messages.error' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let error of errors\" class=\"alert-message\">{{ error }}</li>\n  </ul>\n</nb-alert>\n\n<nb-alert *ngIf=\"showMessages.success && messages?.length && !submitted\" outline=\"success\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.login.messages.success' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let message of messages\" class=\"alert-message\">{{ message }}</li>\n  </ul>\n</nb-alert>\n\n<form (ngSubmit)=\"login()\" #form=\"ngForm\" aria-labelledby=\"title\">\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-email\">{{ 'auth.login.form.input.email.label' | translate }}</label>\n    <input fullWidth [(ngModel)]=\"authLoginReq.email\" #email=\"ngModel\" name=\"email\" id=\"input-email\" pattern=\".+@.+\\..+\"\n      placeholder=\"{{ 'auth.login.form.input.email.placeholder' | translate }}\" fieldSize=\"large\" autofocus\n      [required]=\"config.emailRequired\" [attr.aria-invalid]=\"email.invalid && email.touched ? true : null\" />\n    <ng-container *ngIf=\"email.invalid && email.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"email.errors?.required\">\n        {{ 'auth.login.form.input.email.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"email.errors?.pattern\">\n        {{ 'auth.login.form.input.email.valid_message' | translate }}\n      </p>\n    </ng-container>\n  </div>\n\n  <div class=\"form-control-group\">\n    <span class=\"label-with-link\">\n      <label class=\"label\" for=\"input-password\">\n        {{ 'auth.login.form.input.password.label' | translate }}\n      </label>\n      <a class=\"forgot-password caption-2\" routerLink=\"../request-password\">\n        {{ 'auth.login.form.input.password.forgot_message' | translate }}\n      </a>\n    </span>\n    <input fullWidth [(ngModel)]=\"authLoginReq.password\" #password=\"ngModel\" name=\"password\" type=\"password\"\n      id=\"input-password\" placeholder=\"{{ 'auth.login.form.input.password.placeholder' | translate }}\" fieldSize=\"large\"\n      [required]=\"config.passwordRequired\" [minlength]=\"config.passwordMinLength\" [maxlength]=\"config.passwordMaxLength\"\n      [attr.aria-invalid]=\"password.invalid && password.touched ? true : null\" />\n    <ng-container *ngIf=\"password.invalid && password.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"password.errors?.required\">\n        {{ 'auth.login.form.input.password.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"password.errors?.minlength || password.errors?.maxlength\">\n        {{\n          'auth.login.form.input.password.min_length_message'\n            | translate: { min: config.passwordMinLength, max: config.passwordMaxLength }\n        }}\n      </p>\n    </ng-container>\n  </div>\n\n  <button nbButton fullWidth status=\"primary\" size=\"large\" [disabled]=\"submitted || !form.valid\"\n    [class.btn-pulse]=\"submitted\">\n    {{ 'auth.login.form.button.login' | translate }}\n  </button>\n</form>\n\n<div *ngIf=\"strapiAuthConfig.auth_providers\">\n  <div *ngFor=\"let provider of strapiAuthConfig.auth_providers\">\n    <button class=\"mt-2\" (click)=\"loginProvider(provider)\" nbButton fullWidth status=\"primary\" size=\"large\">\n      <nb-icon *ngIf=\"iconPack.getIcon(provider + '-outline')\" icon=\"{{provider}}-outline\"></nb-icon>\n      {{ 'auth.login.form.button.login_with' | translate }} {{ provider }}\n    </button>\n  </div>\n</div>\n\n<section class=\"another-action\" aria-label=\"Register\">\n  {{ 'auth.login.form.button.register.label' | translate }}\n  <a class=\"text-link\" routerLink=\"../register\">\n    {{ 'auth.login.form.button.register.link' | translate }}\n  </a>\n</section> -->\n", styles: [""], directives: [{ type: i4.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { type: i4.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { type: i4.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { type: i4.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { type: i4.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i4.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { type: i1$1.RouterLinkWithHref, selector: "a[routerLink],area[routerLink]", inputs: ["target", "queryParams", "fragment", "queryParamsHandling", "preserveFragment", "skipLocationChange", "replaceUrl", "state", "relativeTo", "routerLink"] }], pipes: { "translate": i3.TranslatePipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: DefaultLoginComponent, decorators: [{
            type: Component,
            args: [{ selector: 'strapi-default-login', template: "<h1>{{ 'auth.login.title' | translate }}</h1>\n<p>{{ 'auth.login.subtitle' | translate }}</p>\n\n<form [formGroup]=\"formGroup\">\n\n  <div class=\"form-group\">\n    <label class=\"label\" for=\"input-email\">{{ 'auth.login.form.input.email.label' | translate }}</label>\n    <input type=\"email\" class=\"form-control\" id=\"email\" formControlName=\"identifier\"\n      placeholder=\"{{ 'auth.login.form.input.email.placeholder' | translate }}\" />\n  </div>\n\n  <div class=\"form-group\">\n    <label class=\"label\" for=\"input-password\">{{ 'auth.login.form.input.password.label' | translate }}</label>\n    <input type=\"password\" class=\"form-control\" id=\"password\" formControlName=\"password\"\n      placeholder=\"{{ 'auth.login.form.input.password.placeholder' | translate }}\" />\n  </div>\n\n  <div class=\"mt-2\">\n    <button type=\"submit\" class=\"btn btn-primary\" (click)=\"login()\" [disabled]=\"!formGroup.valid\">\n      {{ 'auth.login.form.button.login' | translate }}\n    </button>\n  </div>\n\n  <section class=\"mt-2\" aria-label=\"Register\">\n    {{ 'auth.login.form.button.register.label' | translate }}\n    <a class=\"text-link\" routerLink=\"../register\">\n      {{ 'auth.login.form.button.register.link' | translate }}\n    </a>\n  </section>\n</form>\n\n<!-- <h1 id=\"title\" class=\"title\">{{ 'auth.login.title' | translate }}</h1>\n<p class=\"sub-title\">{{ 'auth.login.subtitle' | translate }}</p>\n\n<nb-alert *ngIf=\"showMessages.error && errors?.length && !submitted\" outline=\"danger\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.login.messages.error' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let error of errors\" class=\"alert-message\">{{ error }}</li>\n  </ul>\n</nb-alert>\n\n<nb-alert *ngIf=\"showMessages.success && messages?.length && !submitted\" outline=\"success\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.login.messages.success' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let message of messages\" class=\"alert-message\">{{ message }}</li>\n  </ul>\n</nb-alert>\n\n<form (ngSubmit)=\"login()\" #form=\"ngForm\" aria-labelledby=\"title\">\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-email\">{{ 'auth.login.form.input.email.label' | translate }}</label>\n    <input fullWidth [(ngModel)]=\"authLoginReq.email\" #email=\"ngModel\" name=\"email\" id=\"input-email\" pattern=\".+@.+\\..+\"\n      placeholder=\"{{ 'auth.login.form.input.email.placeholder' | translate }}\" fieldSize=\"large\" autofocus\n      [required]=\"config.emailRequired\" [attr.aria-invalid]=\"email.invalid && email.touched ? true : null\" />\n    <ng-container *ngIf=\"email.invalid && email.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"email.errors?.required\">\n        {{ 'auth.login.form.input.email.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"email.errors?.pattern\">\n        {{ 'auth.login.form.input.email.valid_message' | translate }}\n      </p>\n    </ng-container>\n  </div>\n\n  <div class=\"form-control-group\">\n    <span class=\"label-with-link\">\n      <label class=\"label\" for=\"input-password\">\n        {{ 'auth.login.form.input.password.label' | translate }}\n      </label>\n      <a class=\"forgot-password caption-2\" routerLink=\"../request-password\">\n        {{ 'auth.login.form.input.password.forgot_message' | translate }}\n      </a>\n    </span>\n    <input fullWidth [(ngModel)]=\"authLoginReq.password\" #password=\"ngModel\" name=\"password\" type=\"password\"\n      id=\"input-password\" placeholder=\"{{ 'auth.login.form.input.password.placeholder' | translate }}\" fieldSize=\"large\"\n      [required]=\"config.passwordRequired\" [minlength]=\"config.passwordMinLength\" [maxlength]=\"config.passwordMaxLength\"\n      [attr.aria-invalid]=\"password.invalid && password.touched ? true : null\" />\n    <ng-container *ngIf=\"password.invalid && password.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"password.errors?.required\">\n        {{ 'auth.login.form.input.password.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"password.errors?.minlength || password.errors?.maxlength\">\n        {{\n          'auth.login.form.input.password.min_length_message'\n            | translate: { min: config.passwordMinLength, max: config.passwordMaxLength }\n        }}\n      </p>\n    </ng-container>\n  </div>\n\n  <button nbButton fullWidth status=\"primary\" size=\"large\" [disabled]=\"submitted || !form.valid\"\n    [class.btn-pulse]=\"submitted\">\n    {{ 'auth.login.form.button.login' | translate }}\n  </button>\n</form>\n\n<div *ngIf=\"strapiAuthConfig.auth_providers\">\n  <div *ngFor=\"let provider of strapiAuthConfig.auth_providers\">\n    <button class=\"mt-2\" (click)=\"loginProvider(provider)\" nbButton fullWidth status=\"primary\" size=\"large\">\n      <nb-icon *ngIf=\"iconPack.getIcon(provider + '-outline')\" icon=\"{{provider}}-outline\"></nb-icon>\n      {{ 'auth.login.form.button.login_with' | translate }} {{ provider }}\n    </button>\n  </div>\n</div>\n\n<section class=\"another-action\" aria-label=\"Register\">\n  {{ 'auth.login.form.button.register.label' | translate }}\n  <a class=\"text-link\" routerLink=\"../register\">\n    {{ 'auth.login.form.button.register.link' | translate }}\n  </a>\n</section> -->\n", styles: [""] }]
        }], ctorParameters: function () {
        return [{ type: AuthService }, { type: i1$1.Router }, { type: i3.TranslateService }, { type: undefined, decorators: [{
                        type: Inject,
                        args: [ConfigServiceInjector]
                    }] }];
    } });

class LogoutBaseComponent {
    constructor(authService, router) {
        this.authService = authService;
        this.router = router;
    }
    ngOnInit() {
        this.logout();
    }
    logout() {
        this.authService.logout().then(() => {
            this.router.navigateByUrl(this.authService.LogoutRedirectUrl);
        });
    }
}
LogoutBaseComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: LogoutBaseComponent, deps: [{ token: AuthService }, { token: i1$1.Router }], target: i0.ɵɵFactoryTarget.Component });
LogoutBaseComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.1", type: LogoutBaseComponent, selector: "strapi-logout-base", ngImport: i0, template: '', isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: LogoutBaseComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'strapi-logout-base',
                    template: ''
                }]
        }], ctorParameters: function () { return [{ type: AuthService }, { type: i1$1.Router }]; } });

class DefaultLogoutComponent extends LogoutBaseComponent {
    constructor(authService, router) {
        super(authService, router);
        this.authService = authService;
        this.router = router;
    }
}
DefaultLogoutComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: DefaultLogoutComponent, deps: [{ token: AuthService }, { token: i1$1.Router }], target: i0.ɵɵFactoryTarget.Component });
DefaultLogoutComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.1", type: DefaultLogoutComponent, selector: "strapi-default-logout", usesInheritance: true, ngImport: i0, template: "<div>\n  {{ 'auth.logout.logout_text' | translate }}\n</div>\n", styles: [""], pipes: { "translate": i3.TranslatePipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: DefaultLogoutComponent, decorators: [{
            type: Component,
            args: [{ selector: 'strapi-default-logout', template: "<div>\n  {{ 'auth.logout.logout_text' | translate }}\n</div>\n", styles: [""] }]
        }], ctorParameters: function () { return [{ type: AuthService }, { type: i1$1.Router }]; } });

class Validation {
    static match(controlName, checkControlName) {
        return (controls) => {
            const control = controls.get(controlName);
            const checkControl = controls.get(checkControlName);
            if (checkControl.errors && !checkControl.errors.matching) {
                return null;
            }
            if (control.value !== checkControl.value) {
                controls.get(checkControlName).setErrors({ matching: true });
                return { matching: true };
            }
            else {
                return null;
            }
        };
    }
}

class RegisterBaseComponent {
    constructor(router, authService, translate) {
        this.router = router;
        this.authService = authService;
        this.translate = translate;
        this.formGroup = new FormGroup({
            email: new FormControl('', [Validators.required, Validators.email]),
            username: new FormControl('', [Validators.required]),
            password: new FormControl('', [Validators.required]),
            passwordConfirmation: new FormControl('', [Validators.required])
        }, {
            validators: [Validation.match('password', 'passwordConfirmation')]
        });
    }
    ngOnInit() {
        if (this.authService.isAuthenticated) {
            this.router.navigateByUrl(this.authService.LoginRedirectUrl);
        }
    }
    register() {
        this.registerReq = this.formGroup.value;
        this.authService
            .register(this.registerReq)
            .then(() => {
            this.router.navigateByUrl(this.authService.LoginUrl);
        })
            .catch((error) => {
            console.log(error);
        });
        // this.authService
        //   .register(
        //     this.authRegisterReq.email,
        //     this.authRegisterReq.username,
        //     this.authRegisterReq.password
        //   )
        //   .then(() => {
        //     this.router.navigateByUrl(this.authService.LoginUrl);
        //   })
        //   .catch((error: HttpErrorResponse) => {
        //     this.submitted = false;
        //     if (error.status === 400) {
        //       this.errors.push(
        //         this.translate.instant('errors.auth.register.password_or_email')
        //       );
        //     } else {
        //       this.errors.push(
        //         this.translate.instant('errors.auth.register.undefined')
        //       );
        //     }
        //   });
    }
}
RegisterBaseComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: RegisterBaseComponent, deps: [{ token: i1$1.Router }, { token: AuthService }, { token: i3.TranslateService }], target: i0.ɵɵFactoryTarget.Component });
RegisterBaseComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.1", type: RegisterBaseComponent, selector: "strapi-register-base", ngImport: i0, template: '', isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: RegisterBaseComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'strapi-register-base',
                    template: ''
                }]
        }], ctorParameters: function () { return [{ type: i1$1.Router }, { type: AuthService }, { type: i3.TranslateService }]; } });

class DefaultRegisterComponent extends RegisterBaseComponent {
    constructor(router, authService, translate) {
        super(router, authService, translate);
        this.router = router;
        this.authService = authService;
        this.translate = translate;
    }
}
DefaultRegisterComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: DefaultRegisterComponent, deps: [{ token: i1$1.Router }, { token: AuthService }, { token: i3.TranslateService }], target: i0.ɵɵFactoryTarget.Component });
DefaultRegisterComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.1", type: DefaultRegisterComponent, selector: "strapi-default-register", usesInheritance: true, ngImport: i0, template: "<h1 id=\"title\" class=\"title\">{{ 'auth.register.title' | translate }}</h1>\n\n<p>{{ 'auth.login.subtitle' | translate }}</p>\n\n<form [formGroup]=\"formGroup\">\n\n\n  <!-- Email -->\n  <div class=\"form-group\">\n    <label class=\"label\" for=\"input-email\">{{ 'auth.register.form.input.email.label' | translate }}</label>\n    <input type=\"email\" class=\"form-control\" id=\"email\" formControlName=\"email\"\n      placeholder=\"{{ 'auth.register.form.input.email.placeholder' | translate }}\" pattern=\".+@.+\\..+\" />\n  </div>\n\n  <!-- Username -->\n  <div class=\"form-group\">\n    <label class=\"label\" for=\"input-username\">{{ 'auth.register.form.input.username.label' | translate }}</label>\n    <input type=\"text\" class=\"form-control\" id=\"username\" formControlName=\"username\"\n      placeholder=\"{{ 'auth.register.form.input.username.placeholder' | translate }}\" />\n  </div>\n\n  <!-- Password -->\n  <div class=\"form-group\">\n    <label class=\"label\" for=\"input-password\">{{ 'auth.register.form.input.password.label' | translate }}</label>\n    <input type=\"password\" class=\"form-control\" id=\"password\" formControlName=\"password\"\n      placeholder=\"{{ 'auth.register.form.input.password.placeholder' | translate }}\" />\n  </div>\n\n  <!-- Password confirmation -->\n  <div class=\"form-group\">\n    <label class=\"label\"\n      for=\"input-password-confirmation\">{{ 'auth.register.form.input.repeat_password.label' | translate }}</label>\n    <input type=\"password\" class=\"form-control\" id=\"password-confirmation\" formControlName=\"passwordConfirmation\"\n      placeholder=\"{{ 'auth.register.form.input.repeat_password.placeholder' | translate }}\" />\n  </div>\n\n  <div class=\"mt-2\">\n    <button type=\"submit\" class=\"btn btn-primary\" (click)=\"register()\" [disabled]=\"!formGroup.valid\">\n      {{ 'auth.register.form.button.register.title' | translate }}\n    </button>\n\n  </div>\n\n  <section class=\"mt-2\" aria-label=\"Sign in\">\n    {{ 'auth.register.form.button.existing_account.text' | translate }}\n    <a class=\"text-link\" routerLink=\"../login\">\n      {{ 'auth.register.form.button.existing_account.title' | translate }}\n    </a>\n  </section>\n\n</form>\n\n<!--\n<nb-alert *ngIf=\"showMessages.error && errors?.length && !submitted\" outline=\"danger\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.register.messages.error' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let error of errors\" class=\"alert-message\">{{ error }}</li>\n  </ul>\n</nb-alert>\n\n<nb-alert *ngIf=\"showMessages.success && messages?.length && !submitted\" outline=\"success\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.register.messages.success' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let message of messages\" class=\"alert-message\">{{ message }}</li>\n  </ul>\n</nb-alert>\n\n<form (ngSubmit)=\"register()\" #form=\"ngForm\" aria-labelledby=\"title\">\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-username\">{{ 'auth.register.form.input.username.label' | translate }}</label>\n    <input nbInput [(ngModel)]=\"authRegisterReq.username\" #username=\"ngModel\" id=\"input-username\" name=\"username\"\n      placeholder=\"{{ 'auth.register.form.input.username.placeholder' | translate }}\" autofocus fullWidth\n      fieldSize=\"large\" [status]=\"username.dirty ? (username.invalid ? 'danger' : 'success') : 'basic'\"\n      [required]=\"config.usernameRequired\" [minlength]=\"config.usernameMinLength\" [maxlength]=\"config.usernameMaxLength\"\n      [attr.aria-invalid]=\"username.invalid && username.touched ? true : null\" />\n    <ng-container *ngIf=\"username.invalid && username.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"username.errors?.required\">\n        {{ 'auth.register.form.input.username.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"username.errors?.minlength || username.errors?.maxlength\">\n        {{\n          'auth.register.form.input.username.min_length_message'\n            | translate: { min: config.lastnameMinLength, max: config.lastnameMaxLength }\n        }}\n      </p>\n    </ng-container>\n  </div>\n\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-email\">{{ 'auth.register.form.input.email.label' | translate }}</label>\n    <input nbInput [(ngModel)]=\"authRegisterReq.email\" #email=\"ngModel\" id=\"input-email\" name=\"email\"\n      pattern=\".+@.+\\..+\" placeholder=\"{{ 'auth.register.form.input.email.placeholder' | translate }}\" fullWidth\n      fieldSize=\"large\" [status]=\"email.dirty ? (email.invalid ? 'danger' : 'success') : 'basic'\"\n      [required]=\"config.emailRequired\" [attr.aria-invalid]=\"email.invalid && email.touched ? true : null\" />\n    <ng-container *ngIf=\"email.invalid && email.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"email.errors?.required\">\n        {{ 'auth.register.form.input.email.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"email.errors?.pattern\">\n        {{ 'auth.register.form.input.email.valid_message' | translate }}\n      </p>\n    </ng-container>\n  </div>\n\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-password\">\n      {{ 'auth.register.form.input.password.label' | translate }}\n    </label>\n    <input nbInput [(ngModel)]=\"authRegisterReq.password\" #password=\"ngModel\" type=\"password\" id=\"input-password\"\n      name=\"password\" placeholder=\"{{ 'auth.register.form.input.password.placeholder' | translate }}\" fullWidth\n      fieldSize=\"large\" [status]=\"password.dirty ? (password.invalid ? 'danger' : 'success') : 'basic'\"\n      pattern=\"(?=.*[a-z])(?=.*[A-Z])(?=.*[0-9])(?=.*[$@$!%*?&])[A-Za-z\\\\d$@$!%*?&].{8,}\"\n      [required]=\"config.passwordRequired\" [minlength]=\"config.passwordMinLength\" [maxlength]=\"config.passwordMaxLength\"\n      [attr.aria-invalid]=\"password.invalid && password.touched ? true : null\" />\n    <ng-container *ngIf=\"password.invalid && password.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"password.errors?.required\">\n        {{ 'auth.register.form.input.password.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"password.errors?.pattern\">\n        {{ 'auth.register.form.input.password.pattern_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"password.errors?.minlength || password.errors?.maxlength\">\n        {{\n          'auth.register.form.input.password.min_length_message'\n            | translate: { min: config.passwordMinLength, max: config.passwordMaxLength }\n        }}\n      </p>\n    </ng-container>\n  </div>\n\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-re-password\">{{\n      'auth.register.form.input.repeat_password.label' | translate\n    }}</label>\n    <input nbInput [(ngModel)]=\"authRegisterReq.password_confirmation\" #rePass=\"ngModel\" type=\"password\"\n      id=\"input-re-password\" name=\"rePass\"\n      placeholder=\"{{ 'auth.register.form.input.repeat_password.placeholder' | translate }}\" fullWidth fieldSize=\"large\"\n      [status]=\"rePass.dirty ? (rePass.invalid || password.value != rePass.value ? 'danger' : 'success') : 'basic'\"\n      [required]=\"config.passwordRequired\" [attr.aria-invalid]=\"rePass.invalid && rePass.touched ? true : null\" />\n    <ng-container *ngIf=\"rePass.invalid && rePass.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"rePass.errors?.required\">\n        {{ 'auth.register.form.input.repeat_password.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"password.value != rePass.value && !rePass.errors?.required\">\n        {{ 'auth.register.form.input.repeat_password.match_message' | translate }}\n      </p>\n    </ng-container>\n  </div>\n\n  <button nbButton fullWidth status=\"primary\" size=\"large\"\n    [disabled]=\"submitted || !form.valid || password.value !== rePass.value\" [class.btn-pulse]=\"submitted\">\n    {{ 'auth.register.form.button.register.title' | translate }}\n  </button>\n</form>\n\n<section class=\"another-action\" aria-label=\"Sign in\">\n  {{ 'auth.register.form.button.existing_account.text' | translate }}\n  <a class=\"text-link\" routerLink=\"../login\">\n    {{ 'auth.register.form.button.existing_account.title' | translate }}\n  </a>\n</section> -->\n", styles: [""], directives: [{ type: i4.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { type: i4.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { type: i4.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { type: i4.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { type: i4.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i4.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { type: i4.PatternValidator, selector: "[pattern][formControlName],[pattern][formControl],[pattern][ngModel]", inputs: ["pattern"] }, { type: i1$1.RouterLinkWithHref, selector: "a[routerLink],area[routerLink]", inputs: ["target", "queryParams", "fragment", "queryParamsHandling", "preserveFragment", "skipLocationChange", "replaceUrl", "state", "relativeTo", "routerLink"] }], pipes: { "translate": i3.TranslatePipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: DefaultRegisterComponent, decorators: [{
            type: Component,
            args: [{ selector: 'strapi-default-register', template: "<h1 id=\"title\" class=\"title\">{{ 'auth.register.title' | translate }}</h1>\n\n<p>{{ 'auth.login.subtitle' | translate }}</p>\n\n<form [formGroup]=\"formGroup\">\n\n\n  <!-- Email -->\n  <div class=\"form-group\">\n    <label class=\"label\" for=\"input-email\">{{ 'auth.register.form.input.email.label' | translate }}</label>\n    <input type=\"email\" class=\"form-control\" id=\"email\" formControlName=\"email\"\n      placeholder=\"{{ 'auth.register.form.input.email.placeholder' | translate }}\" pattern=\".+@.+\\..+\" />\n  </div>\n\n  <!-- Username -->\n  <div class=\"form-group\">\n    <label class=\"label\" for=\"input-username\">{{ 'auth.register.form.input.username.label' | translate }}</label>\n    <input type=\"text\" class=\"form-control\" id=\"username\" formControlName=\"username\"\n      placeholder=\"{{ 'auth.register.form.input.username.placeholder' | translate }}\" />\n  </div>\n\n  <!-- Password -->\n  <div class=\"form-group\">\n    <label class=\"label\" for=\"input-password\">{{ 'auth.register.form.input.password.label' | translate }}</label>\n    <input type=\"password\" class=\"form-control\" id=\"password\" formControlName=\"password\"\n      placeholder=\"{{ 'auth.register.form.input.password.placeholder' | translate }}\" />\n  </div>\n\n  <!-- Password confirmation -->\n  <div class=\"form-group\">\n    <label class=\"label\"\n      for=\"input-password-confirmation\">{{ 'auth.register.form.input.repeat_password.label' | translate }}</label>\n    <input type=\"password\" class=\"form-control\" id=\"password-confirmation\" formControlName=\"passwordConfirmation\"\n      placeholder=\"{{ 'auth.register.form.input.repeat_password.placeholder' | translate }}\" />\n  </div>\n\n  <div class=\"mt-2\">\n    <button type=\"submit\" class=\"btn btn-primary\" (click)=\"register()\" [disabled]=\"!formGroup.valid\">\n      {{ 'auth.register.form.button.register.title' | translate }}\n    </button>\n\n  </div>\n\n  <section class=\"mt-2\" aria-label=\"Sign in\">\n    {{ 'auth.register.form.button.existing_account.text' | translate }}\n    <a class=\"text-link\" routerLink=\"../login\">\n      {{ 'auth.register.form.button.existing_account.title' | translate }}\n    </a>\n  </section>\n\n</form>\n\n<!--\n<nb-alert *ngIf=\"showMessages.error && errors?.length && !submitted\" outline=\"danger\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.register.messages.error' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let error of errors\" class=\"alert-message\">{{ error }}</li>\n  </ul>\n</nb-alert>\n\n<nb-alert *ngIf=\"showMessages.success && messages?.length && !submitted\" outline=\"success\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.register.messages.success' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let message of messages\" class=\"alert-message\">{{ message }}</li>\n  </ul>\n</nb-alert>\n\n<form (ngSubmit)=\"register()\" #form=\"ngForm\" aria-labelledby=\"title\">\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-username\">{{ 'auth.register.form.input.username.label' | translate }}</label>\n    <input nbInput [(ngModel)]=\"authRegisterReq.username\" #username=\"ngModel\" id=\"input-username\" name=\"username\"\n      placeholder=\"{{ 'auth.register.form.input.username.placeholder' | translate }}\" autofocus fullWidth\n      fieldSize=\"large\" [status]=\"username.dirty ? (username.invalid ? 'danger' : 'success') : 'basic'\"\n      [required]=\"config.usernameRequired\" [minlength]=\"config.usernameMinLength\" [maxlength]=\"config.usernameMaxLength\"\n      [attr.aria-invalid]=\"username.invalid && username.touched ? true : null\" />\n    <ng-container *ngIf=\"username.invalid && username.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"username.errors?.required\">\n        {{ 'auth.register.form.input.username.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"username.errors?.minlength || username.errors?.maxlength\">\n        {{\n          'auth.register.form.input.username.min_length_message'\n            | translate: { min: config.lastnameMinLength, max: config.lastnameMaxLength }\n        }}\n      </p>\n    </ng-container>\n  </div>\n\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-email\">{{ 'auth.register.form.input.email.label' | translate }}</label>\n    <input nbInput [(ngModel)]=\"authRegisterReq.email\" #email=\"ngModel\" id=\"input-email\" name=\"email\"\n      pattern=\".+@.+\\..+\" placeholder=\"{{ 'auth.register.form.input.email.placeholder' | translate }}\" fullWidth\n      fieldSize=\"large\" [status]=\"email.dirty ? (email.invalid ? 'danger' : 'success') : 'basic'\"\n      [required]=\"config.emailRequired\" [attr.aria-invalid]=\"email.invalid && email.touched ? true : null\" />\n    <ng-container *ngIf=\"email.invalid && email.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"email.errors?.required\">\n        {{ 'auth.register.form.input.email.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"email.errors?.pattern\">\n        {{ 'auth.register.form.input.email.valid_message' | translate }}\n      </p>\n    </ng-container>\n  </div>\n\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-password\">\n      {{ 'auth.register.form.input.password.label' | translate }}\n    </label>\n    <input nbInput [(ngModel)]=\"authRegisterReq.password\" #password=\"ngModel\" type=\"password\" id=\"input-password\"\n      name=\"password\" placeholder=\"{{ 'auth.register.form.input.password.placeholder' | translate }}\" fullWidth\n      fieldSize=\"large\" [status]=\"password.dirty ? (password.invalid ? 'danger' : 'success') : 'basic'\"\n      pattern=\"(?=.*[a-z])(?=.*[A-Z])(?=.*[0-9])(?=.*[$@$!%*?&])[A-Za-z\\\\d$@$!%*?&].{8,}\"\n      [required]=\"config.passwordRequired\" [minlength]=\"config.passwordMinLength\" [maxlength]=\"config.passwordMaxLength\"\n      [attr.aria-invalid]=\"password.invalid && password.touched ? true : null\" />\n    <ng-container *ngIf=\"password.invalid && password.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"password.errors?.required\">\n        {{ 'auth.register.form.input.password.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"password.errors?.pattern\">\n        {{ 'auth.register.form.input.password.pattern_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"password.errors?.minlength || password.errors?.maxlength\">\n        {{\n          'auth.register.form.input.password.min_length_message'\n            | translate: { min: config.passwordMinLength, max: config.passwordMaxLength }\n        }}\n      </p>\n    </ng-container>\n  </div>\n\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-re-password\">{{\n      'auth.register.form.input.repeat_password.label' | translate\n    }}</label>\n    <input nbInput [(ngModel)]=\"authRegisterReq.password_confirmation\" #rePass=\"ngModel\" type=\"password\"\n      id=\"input-re-password\" name=\"rePass\"\n      placeholder=\"{{ 'auth.register.form.input.repeat_password.placeholder' | translate }}\" fullWidth fieldSize=\"large\"\n      [status]=\"rePass.dirty ? (rePass.invalid || password.value != rePass.value ? 'danger' : 'success') : 'basic'\"\n      [required]=\"config.passwordRequired\" [attr.aria-invalid]=\"rePass.invalid && rePass.touched ? true : null\" />\n    <ng-container *ngIf=\"rePass.invalid && rePass.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"rePass.errors?.required\">\n        {{ 'auth.register.form.input.repeat_password.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"password.value != rePass.value && !rePass.errors?.required\">\n        {{ 'auth.register.form.input.repeat_password.match_message' | translate }}\n      </p>\n    </ng-container>\n  </div>\n\n  <button nbButton fullWidth status=\"primary\" size=\"large\"\n    [disabled]=\"submitted || !form.valid || password.value !== rePass.value\" [class.btn-pulse]=\"submitted\">\n    {{ 'auth.register.form.button.register.title' | translate }}\n  </button>\n</form>\n\n<section class=\"another-action\" aria-label=\"Sign in\">\n  {{ 'auth.register.form.button.existing_account.text' | translate }}\n  <a class=\"text-link\" routerLink=\"../login\">\n    {{ 'auth.register.form.button.existing_account.title' | translate }}\n  </a>\n</section> -->\n", styles: [""] }]
        }], ctorParameters: function () { return [{ type: i1$1.Router }, { type: AuthService }, { type: i3.TranslateService }]; } });

class RequestPasswordBaseComponent {
    constructor(cd, router, authService, translate) {
        this.cd = cd;
        this.router = router;
        this.authService = authService;
        this.translate = translate;
        this.redirectDelay = 0;
        this.showMessages = {
            error: true,
            success: true
        };
        this.resetCreateReq = {
            email: ''
        };
        this.submitted = false;
        this.errors = [];
        this.messages = [];
        this.config = {
            emailRequired: true
        };
    }
    ngOnInit() { }
    ngOnDestroy() { }
    requestPass() {
        this.errors = [];
        this.messages = [];
        this.submitted = true;
        this.authService
            .requestPasswordReset(this.resetCreateReq.email)
            .then(() => {
            this.submitted = false;
            this.resetCreateReq.email = '';
            this.router.navigateByUrl(this.authService.RequestPasswordRedirectUrl);
        })
            .catch((error) => {
            this.submitted = false;
            if (error.status === 400) {
                this.errors.push(this.translate.instant('errors.auth.request-password.email'));
            }
            else {
                this.errors.push(this.translate.instant('errors.auth.request-password.undefined'));
            }
        });
    }
}
RequestPasswordBaseComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: RequestPasswordBaseComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i1$1.Router }, { token: AuthService }, { token: i3.TranslateService }], target: i0.ɵɵFactoryTarget.Component });
RequestPasswordBaseComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.1", type: RequestPasswordBaseComponent, selector: "strapi-request-password-base", ngImport: i0, template: '', isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: RequestPasswordBaseComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'strapi-request-password-base',
                    template: ''
                }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }, { type: i1$1.Router }, { type: AuthService }, { type: i3.TranslateService }]; } });

class DefaultRequestPasswordComponent extends RequestPasswordBaseComponent {
    constructor(cd, router, authService, translate) {
        super(cd, router, authService, translate);
        this.cd = cd;
        this.router = router;
        this.authService = authService;
        this.translate = translate;
    }
    ngOnInit() { }
}
DefaultRequestPasswordComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: DefaultRequestPasswordComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i1$1.Router }, { token: AuthService }, { token: i3.TranslateService }], target: i0.ɵɵFactoryTarget.Component });
DefaultRequestPasswordComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.1", type: DefaultRequestPasswordComponent, selector: "strapi-default-request-password", usesInheritance: true, ngImport: i0, template: "<h1 id=\"title\" class=\"title\">{{ 'auth.request_password.title' | translate }}</h1>\n<!-- <p class=\"sub-title\">{{ 'auth.request_password.subtitle' | translate }}</p>\n\n<nb-alert *ngIf=\"showMessages.error && errors?.length && !submitted\" outline=\"danger\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.request_password.messages.error' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let error of errors\" class=\"alert-message\">{{ error }}</li>\n  </ul>\n</nb-alert>\n\n<nb-alert *ngIf=\"showMessages.success && messages?.length && !submitted\" outline=\"success\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.request_password.messages.success' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let message of messages\" class=\"alert-message\">{{ message }}</li>\n  </ul>\n</nb-alert>\n\n<form (ngSubmit)=\"requestPass()\" #requestPassForm=\"ngForm\" aria-labelledby=\"title\">\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-email\">{{ 'auth.request_password.form.input.email.label' | translate }}</label>\n    <input nbInput [(ngModel)]=\"resetCreateReq.email\" #email=\"ngModel\" id=\"input-email\" name=\"email\" pattern=\".+@.+\\..+\"\n      placeholder=\"{{ 'auth.request_password.form.input.email.placeholder' | translate }}\" autofocus fullWidth\n      fieldSize=\"large\" [status]=\"email.dirty ? (email.invalid ? 'danger' : 'success') : 'basic'\"\n      [required]=\"config.emailRequired\" [attr.aria-invalid]=\"email.invalid && email.touched ? true : null\" />\n    <ng-container *ngIf=\"email.invalid && email.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"email.errors?.required\">\n        {{ 'auth.request_password.form.input.email.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"email.errors?.pattern\">\n        {{ 'auth.request_password.form.input.email.valid_message' | translate }}\n      </p>\n    </ng-container>\n  </div>\n\n  <button nbButton fullWidth status=\"primary\" size=\"large\" [disabled]=\"submitted || !requestPassForm.valid\"\n    [class.btn-pulse]=\"submitted\">\n    {{ 'auth.request_password.form.button.request.title' | translate }}\n  </button>\n</form>\n\n<section class=\"sign-in-or-up\" aria-label=\"Sign in or sign up\">\n  <p>\n    <a class=\"text-link\" routerLink=\"../login\">\n      {{ 'auth.request_password.form.button.back_to.text' | translate }}\n    </a>\n  </p>\n  <p>\n    <a routerLink=\"../register\" class=\"text-link\">\n      {{ 'auth.request_password.form.button.back_to.title' | translate }}\n    </a>\n  </p>\n</section> -->\n", styles: [""], pipes: { "translate": i3.TranslatePipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: DefaultRequestPasswordComponent, decorators: [{
            type: Component,
            args: [{ selector: 'strapi-default-request-password', template: "<h1 id=\"title\" class=\"title\">{{ 'auth.request_password.title' | translate }}</h1>\n<!-- <p class=\"sub-title\">{{ 'auth.request_password.subtitle' | translate }}</p>\n\n<nb-alert *ngIf=\"showMessages.error && errors?.length && !submitted\" outline=\"danger\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.request_password.messages.error' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let error of errors\" class=\"alert-message\">{{ error }}</li>\n  </ul>\n</nb-alert>\n\n<nb-alert *ngIf=\"showMessages.success && messages?.length && !submitted\" outline=\"success\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.request_password.messages.success' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let message of messages\" class=\"alert-message\">{{ message }}</li>\n  </ul>\n</nb-alert>\n\n<form (ngSubmit)=\"requestPass()\" #requestPassForm=\"ngForm\" aria-labelledby=\"title\">\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-email\">{{ 'auth.request_password.form.input.email.label' | translate }}</label>\n    <input nbInput [(ngModel)]=\"resetCreateReq.email\" #email=\"ngModel\" id=\"input-email\" name=\"email\" pattern=\".+@.+\\..+\"\n      placeholder=\"{{ 'auth.request_password.form.input.email.placeholder' | translate }}\" autofocus fullWidth\n      fieldSize=\"large\" [status]=\"email.dirty ? (email.invalid ? 'danger' : 'success') : 'basic'\"\n      [required]=\"config.emailRequired\" [attr.aria-invalid]=\"email.invalid && email.touched ? true : null\" />\n    <ng-container *ngIf=\"email.invalid && email.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"email.errors?.required\">\n        {{ 'auth.request_password.form.input.email.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"email.errors?.pattern\">\n        {{ 'auth.request_password.form.input.email.valid_message' | translate }}\n      </p>\n    </ng-container>\n  </div>\n\n  <button nbButton fullWidth status=\"primary\" size=\"large\" [disabled]=\"submitted || !requestPassForm.valid\"\n    [class.btn-pulse]=\"submitted\">\n    {{ 'auth.request_password.form.button.request.title' | translate }}\n  </button>\n</form>\n\n<section class=\"sign-in-or-up\" aria-label=\"Sign in or sign up\">\n  <p>\n    <a class=\"text-link\" routerLink=\"../login\">\n      {{ 'auth.request_password.form.button.back_to.text' | translate }}\n    </a>\n  </p>\n  <p>\n    <a routerLink=\"../register\" class=\"text-link\">\n      {{ 'auth.request_password.form.button.back_to.title' | translate }}\n    </a>\n  </p>\n</section> -->\n", styles: [""] }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }, { type: i1$1.Router }, { type: AuthService }, { type: i3.TranslateService }]; } });

class ResetPasswordBaseComponent {
    constructor(cd, router, route, authService, translate) {
        this.cd = cd;
        this.router = router;
        this.route = route;
        this.authService = authService;
        this.translate = translate;
        this.redirectDelay = 0;
        this.showMessages = {
            error: true,
            success: true
        };
        this.strategy = '';
        this.submitted = false;
        this.errors = [];
        this.messages = [];
        this.passwordResetReq = {
            password_confirmation: '',
            password: '',
            reset_token: ''
        };
        this.config = {
            fullNameRequired: true,
            fullNameMinLength: 2,
            fullNameMaxLength: 100,
            emailRequired: true,
            passwordRequired: true,
            passwordMinLength: 6,
            passwordMaxLength: 60,
            termsRequired: true
        };
    }
    ngOnInit() {
        // get code from url
        this.route.queryParams.subscribe(() => {
            this.passwordResetReq.code =
                this.route.snapshot.queryParamMap.get('code');
        });
        if (!this.passwordResetReq.code) {
            console.error('Reset token not found!');
        }
    }
    ngOnDestroy() { }
    resetPass() {
        this.errors = [];
        this.messages = [];
        this.submitted = true;
        this.authService
            .resetPassword(this.passwordResetReq)
            .then(() => {
            this.submitted = false;
            this.router.navigateByUrl(this.authService.LoginUrl);
        })
            .catch((error) => {
            this.submitted = false;
            if (error.status === 400) {
                this.errors.push(this.translate.instant('errors.auth.reset-password.code'));
            }
            else {
                this.errors.push(this.translate.instant('errors.auth.reset-password.undefined'));
            }
        });
    }
}
ResetPasswordBaseComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: ResetPasswordBaseComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i1$1.Router }, { token: i1$1.ActivatedRoute }, { token: AuthService }, { token: i3.TranslateService }], target: i0.ɵɵFactoryTarget.Component });
ResetPasswordBaseComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.1", type: ResetPasswordBaseComponent, selector: "strapi-reset-password-base", ngImport: i0, template: '', isInline: true });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: ResetPasswordBaseComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'strapi-reset-password-base',
                    template: ''
                }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }, { type: i1$1.Router }, { type: i1$1.ActivatedRoute }, { type: AuthService }, { type: i3.TranslateService }]; } });

class DefaultResetPasswordComponent extends ResetPasswordBaseComponent {
    constructor(cd, router, route, authService, translate) {
        super(cd, router, route, authService, translate);
        this.cd = cd;
        this.router = router;
        this.route = route;
        this.authService = authService;
        this.translate = translate;
    }
    ngOnInit() { }
}
DefaultResetPasswordComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: DefaultResetPasswordComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i1$1.Router }, { token: i1$1.ActivatedRoute }, { token: AuthService }, { token: i3.TranslateService }], target: i0.ɵɵFactoryTarget.Component });
DefaultResetPasswordComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.1", type: DefaultResetPasswordComponent, selector: "strapi-default-reset-password", usesInheritance: true, ngImport: i0, template: "<h1 id=\"title\" class=\"title\">{{ 'auth.change_password.title' | translate }}</h1>\n<!-- <p class=\"sub-title\">{{ 'auth.change_password.subtitle' | translate }}</p>\n\n<nb-alert *ngIf=\"showMessages.error && errors?.length && !submitted\" outline=\"danger\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.change_password.messages.error' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let error of errors\" class=\"alert-message\">{{ error }}</li>\n  </ul>\n</nb-alert>\n\n<nb-alert *ngIf=\"showMessages.success && messages?.length && !submitted\" outline=\"success\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.change_password.messages.success' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let message of messages\" class=\"alert-message\">{{ message }}</li>\n  </ul>\n</nb-alert>\n\n<form (ngSubmit)=\"resetPass()\" #resetPassForm=\"ngForm\" aria-labelledby=\"title\">\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-password\">\n      {{ 'auth.register.form.input.password.label' | translate }}\n    </label>\n    <input nbInput [(ngModel)]=\"passwordResetReq.password\" #password=\"ngModel\" type=\"password\" id=\"input-password\"\n      name=\"password\" placeholder=\"{{ 'auth.register.form.input.password.placeholder' | translate }}\" fullWidth\n      fieldSize=\"large\" [status]=\"password.dirty ? (password.invalid ? 'danger' : 'success') : 'basic'\"\n      [required]=\"config.passwordRequired\" [minlength]=\"config.passwordMinLength\" [maxlength]=\"config.passwordMaxLength\"\n      [attr.aria-invalid]=\"password.invalid && password.touched ? true : null\" />\n    <ng-container *ngIf=\"password.invalid && password.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"password.errors?.required\">\n        {{ 'auth.register.form.input.password.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"password.errors?.minlength || password.errors?.maxlength\">\n        {{\n          'auth.register.form.input.password.min_length_message'\n            | translate: { min: config.passwordMinLength, max: config.passwordMaxLength }\n        }}\n      </p>\n    </ng-container>\n  </div>\n\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-re-password\">{{\n      'auth.register.form.input.repeat_password.label' | translate\n    }}</label>\n    <input nbInput [(ngModel)]=\"passwordResetReq.passwordConfirmation\" #rePass=\"ngModel\" type=\"password\"\n      id=\"input-re-password\" name=\"rePass\"\n      placeholder=\"{{ 'auth.register.form.input.repeat_password.placeholder' | translate }}\" fullWidth fieldSize=\"large\"\n      [status]=\"rePass.dirty ? (rePass.invalid || password.value != rePass.value ? 'danger' : 'success') : 'basic'\"\n      [required]=\"config.passwordRequired\" [attr.aria-invalid]=\"rePass.invalid && rePass.touched ? true : null\" />\n    <ng-container *ngIf=\"rePass.invalid && rePass.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"rePass.errors?.required\">\n        {{ 'auth.register.form.input.repeat_password.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"password.value != rePass.value && !rePass.errors?.required\">\n        {{ 'auth.register.form.input.repeat_password.match_message' | translate }}\n      </p>\n    </ng-container>\n  </div>\n\n  <button nbButton status=\"primary\" fullWidth size=\"large\"\n    [disabled]=\"submitted || !resetPassForm.valid || rePass.value !== password.value\" [class.btn-pulse]=\"submitted\">\n    {{ 'auth.change_password.form.button.change_password.title' | translate }}\n  </button>\n</form>\n\n<section class=\"sign-in-or-up\" aria-label=\"Sign in or sign up\">\n  <p>\n    <a class=\"text-link\" routerLink=\"../login\">{{ 'auth.change_password.form.button.back_to.text' | translate }}</a>\n  </p>\n  <p>\n    <a class=\"text-link\" routerLink=\"../register\">{{\n      'auth.change_password.form.button.back_to.title' | translate\n    }}</a>\n  </p>\n</section> -->\n", styles: [""], pipes: { "translate": i3.TranslatePipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: DefaultResetPasswordComponent, decorators: [{
            type: Component,
            args: [{ selector: 'strapi-default-reset-password', template: "<h1 id=\"title\" class=\"title\">{{ 'auth.change_password.title' | translate }}</h1>\n<!-- <p class=\"sub-title\">{{ 'auth.change_password.subtitle' | translate }}</p>\n\n<nb-alert *ngIf=\"showMessages.error && errors?.length && !submitted\" outline=\"danger\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.change_password.messages.error' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let error of errors\" class=\"alert-message\">{{ error }}</li>\n  </ul>\n</nb-alert>\n\n<nb-alert *ngIf=\"showMessages.success && messages?.length && !submitted\" outline=\"success\" role=\"alert\">\n  <p class=\"alert-title\">\n    <b>{{ 'auth.change_password.messages.success' | translate }}</b>\n  </p>\n  <ul class=\"alert-message-list\">\n    <li *ngFor=\"let message of messages\" class=\"alert-message\">{{ message }}</li>\n  </ul>\n</nb-alert>\n\n<form (ngSubmit)=\"resetPass()\" #resetPassForm=\"ngForm\" aria-labelledby=\"title\">\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-password\">\n      {{ 'auth.register.form.input.password.label' | translate }}\n    </label>\n    <input nbInput [(ngModel)]=\"passwordResetReq.password\" #password=\"ngModel\" type=\"password\" id=\"input-password\"\n      name=\"password\" placeholder=\"{{ 'auth.register.form.input.password.placeholder' | translate }}\" fullWidth\n      fieldSize=\"large\" [status]=\"password.dirty ? (password.invalid ? 'danger' : 'success') : 'basic'\"\n      [required]=\"config.passwordRequired\" [minlength]=\"config.passwordMinLength\" [maxlength]=\"config.passwordMaxLength\"\n      [attr.aria-invalid]=\"password.invalid && password.touched ? true : null\" />\n    <ng-container *ngIf=\"password.invalid && password.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"password.errors?.required\">\n        {{ 'auth.register.form.input.password.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"password.errors?.minlength || password.errors?.maxlength\">\n        {{\n          'auth.register.form.input.password.min_length_message'\n            | translate: { min: config.passwordMinLength, max: config.passwordMaxLength }\n        }}\n      </p>\n    </ng-container>\n  </div>\n\n  <div class=\"form-control-group\">\n    <label class=\"label\" for=\"input-re-password\">{{\n      'auth.register.form.input.repeat_password.label' | translate\n    }}</label>\n    <input nbInput [(ngModel)]=\"passwordResetReq.passwordConfirmation\" #rePass=\"ngModel\" type=\"password\"\n      id=\"input-re-password\" name=\"rePass\"\n      placeholder=\"{{ 'auth.register.form.input.repeat_password.placeholder' | translate }}\" fullWidth fieldSize=\"large\"\n      [status]=\"rePass.dirty ? (rePass.invalid || password.value != rePass.value ? 'danger' : 'success') : 'basic'\"\n      [required]=\"config.passwordRequired\" [attr.aria-invalid]=\"rePass.invalid && rePass.touched ? true : null\" />\n    <ng-container *ngIf=\"rePass.invalid && rePass.touched\">\n      <p class=\"caption status-danger\" *ngIf=\"rePass.errors?.required\">\n        {{ 'auth.register.form.input.repeat_password.required_message' | translate }}\n      </p>\n      <p class=\"caption status-danger\" *ngIf=\"password.value != rePass.value && !rePass.errors?.required\">\n        {{ 'auth.register.form.input.repeat_password.match_message' | translate }}\n      </p>\n    </ng-container>\n  </div>\n\n  <button nbButton status=\"primary\" fullWidth size=\"large\"\n    [disabled]=\"submitted || !resetPassForm.valid || rePass.value !== password.value\" [class.btn-pulse]=\"submitted\">\n    {{ 'auth.change_password.form.button.change_password.title' | translate }}\n  </button>\n</form>\n\n<section class=\"sign-in-or-up\" aria-label=\"Sign in or sign up\">\n  <p>\n    <a class=\"text-link\" routerLink=\"../login\">{{ 'auth.change_password.form.button.back_to.text' | translate }}</a>\n  </p>\n  <p>\n    <a class=\"text-link\" routerLink=\"../register\">{{\n      'auth.change_password.form.button.back_to.title' | translate\n    }}</a>\n  </p>\n</section> -->\n", styles: [""] }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }, { type: i1$1.Router }, { type: i1$1.ActivatedRoute }, { type: AuthService }, { type: i3.TranslateService }]; } });

class TemplateService {
    constructor(_config) {
        this._config = _config;
        this.templates = {};
        this.config = this._config;
        this.setDefaultTemplates();
        this.mapTemplates();
    }
    /**
     * Get component by ControlType
     * @param authComponent
     * @returns Component
     */
    getComponent(authComponent) {
        return this.getComponentByType(authComponent);
    }
    /**
     * Inject component for specific template
     * @param template
     * @param authComponent
     */
    setTemplate(template, authComponent) {
        this.templates[authComponent] = template;
    }
    /**
     * Get all registered templates
     */
    get RegisteredTemplates() {
        return this.templates;
    }
    // TODO: Add template functionality for every component
    /**
     * Set all default templates for each component
     */
    setDefaultTemplates() {
        this.templates[AuthComponents$1.Login] = DefaultLoginComponent;
        this.templates[AuthComponents$1.Logout] = DefaultLogoutComponent;
        this.templates[AuthComponents$1.Register] =
            DefaultRegisterComponent;
        this.templates[AuthComponents$1.RequestPassword] =
            DefaultRequestPasswordComponent;
        this.templates[AuthComponents$1.ResetPassword] =
            DefaultResetPasswordComponent;
    }
    /**
     * Map all templates
     */
    mapTemplates() {
        if (this.config && this.config.templates) {
            for (const templateName in this.config.templates) {
                const template = this.config.templates[templateName];
                this.templates[templateName] = template;
            }
        }
    }
    /**
     * Get component by ControlType
     * @param authComponent
     * @returns Component
     */
    getComponentByType(authComponent) {
        return this.templates[authComponent];
    }
}
TemplateService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: TemplateService, deps: [{ token: ConfigServiceInjector }], target: i0.ɵɵFactoryTarget.Injectable });
TemplateService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: TemplateService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: TemplateService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Inject,
                        args: [ConfigServiceInjector]
                    }] }];
    } });

class DynamicComponentDirective {
    constructor(resolver, container, renderer, templateService) {
        this.resolver = resolver;
        this.container = container;
        this.renderer = renderer;
        this.templateService = templateService;
        this.componentRef = null;
        this.authComponent = null;
    }
    ngOnInit() {
        if (this.authComponent && this.authComponent) {
            const component = this.templateService.getComponent(this.authComponent);
            if (component) {
                const factory = this.resolver.resolveComponentFactory(component);
                this.componentRef = this.container.createComponent(factory);
                this.componentRef.instance.dynamicControl = this.authComponent;
            }
        }
    }
}
DynamicComponentDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: DynamicComponentDirective, deps: [{ token: i0.ComponentFactoryResolver }, { token: i0.ViewContainerRef }, { token: i0.Renderer2 }, { token: TemplateService }], target: i0.ɵɵFactoryTarget.Directive });
DynamicComponentDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "13.3.1", type: DynamicComponentDirective, selector: "[strapiDynamicComponent]", inputs: { authComponent: "authComponent" }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: DynamicComponentDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[strapiDynamicComponent]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ComponentFactoryResolver }, { type: i0.ViewContainerRef }, { type: i0.Renderer2 }, { type: TemplateService }]; }, propDecorators: { authComponent: [{
                type: Input
            }] } });

class StrapiAuthModule {
    static forRoot(config) {
        return {
            ngModule: StrapiAuthModule,
            providers: [
                AuthService,
                TokenService,
                AuthInterceptor,
                LanguageService,
                {
                    provide: ConfigServiceInjector,
                    useValue: config
                }
            ]
        };
    }
}
StrapiAuthModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: StrapiAuthModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
StrapiAuthModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: StrapiAuthModule, declarations: [ProfileComponent,
        ValidationComponent,
        DynamicComponentDirective,
        DefaultLoginComponent,
        DefaultRegisterComponent,
        DefaultLogoutComponent,
        DefaultRequestPasswordComponent,
        DefaultResetPasswordComponent,
        LoginBaseComponent,
        RegisterBaseComponent,
        LogoutBaseComponent,
        RequestPasswordBaseComponent,
        ResetPasswordBaseComponent], imports: [CommonModule,
        FormsModule,
        ReactiveFormsModule,
        RouterModule,
        TranslateModule], exports: [ProfileComponent,
        ValidationComponent,
        DefaultLoginComponent,
        DefaultRegisterComponent,
        DefaultLogoutComponent,
        DefaultRequestPasswordComponent,
        DefaultResetPasswordComponent,
        LoginBaseComponent,
        RegisterBaseComponent,
        LogoutBaseComponent,
        RequestPasswordBaseComponent,
        ResetPasswordBaseComponent] });
StrapiAuthModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: StrapiAuthModule, imports: [[
            CommonModule,
            FormsModule,
            ReactiveFormsModule,
            RouterModule,
            TranslateModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: StrapiAuthModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        ProfileComponent,
                        ValidationComponent,
                        DynamicComponentDirective,
                        DefaultLoginComponent,
                        DefaultRegisterComponent,
                        DefaultLogoutComponent,
                        DefaultRequestPasswordComponent,
                        DefaultResetPasswordComponent,
                        LoginBaseComponent,
                        RegisterBaseComponent,
                        LogoutBaseComponent,
                        RequestPasswordBaseComponent,
                        ResetPasswordBaseComponent
                    ],
                    imports: [
                        CommonModule,
                        FormsModule,
                        ReactiveFormsModule,
                        RouterModule,
                        TranslateModule
                    ],
                    exports: [
                        ProfileComponent,
                        ValidationComponent,
                        DefaultLoginComponent,
                        DefaultRegisterComponent,
                        DefaultLogoutComponent,
                        DefaultRequestPasswordComponent,
                        DefaultResetPasswordComponent,
                        LoginBaseComponent,
                        RegisterBaseComponent,
                        LogoutBaseComponent,
                        RequestPasswordBaseComponent,
                        ResetPasswordBaseComponent
                    ]
                }]
        }] });

class AuthGuard {
    constructor(authService, router) {
        this.authService = authService;
        this.router = router;
    }
    canActivate(next, state) {
        return this.checkAuthState();
    }
    canActivateChild(next, state) {
        return this.checkAuthState();
    }
    checkAuthState() {
        const authState = this.authService.isAuthenticated;
        if (!authState) {
            this.router.navigateByUrl(this.authService.LoginUrl);
            return false;
        }
        return true;
    }
}
AuthGuard.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: AuthGuard, deps: [{ token: AuthService }, { token: i1$1.Router }], target: i0.ɵɵFactoryTarget.Injectable });
AuthGuard.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: AuthGuard, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: AuthGuard, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: AuthService }, { type: i1$1.Router }]; } });

class TokenGuard {
    constructor(authService, router) {
        this.authService = authService;
        this.router = router;
    }
    canActivate(route, state) {
        return this.checkUrlToken(route);
    }
    canActivateChild(childRoute, state) {
        return this.checkUrlToken(childRoute);
    }
    /*
     * Checks Token in URL
     */
    checkUrlToken(route) {
        const url = window.location.href;
        if (!this.authService.isAuthenticated && url.includes('?')) {
            const paramsUrl = window.location.href.split('?').pop();
            if (paramsUrl.length) {
                this.authService
                    .callbackProviderLogin(paramsUrl, route.routeConfig.path)
                    .then(() => {
                    this.router.navigateByUrl(this.authService.LoginRedirectUrl);
                });
            }
        }
        return true;
    }
}
TokenGuard.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: TokenGuard, deps: [{ token: AuthService }, { token: i1$1.Router }], target: i0.ɵɵFactoryTarget.Injectable });
TokenGuard.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: TokenGuard, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: TokenGuard, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: AuthService }, { type: i1$1.Router }]; } });

// eslint-disable-next-line @typescript-eslint/naming-convention
class BaseModel {
    constructor() {
        // eslint-disable-next-line @typescript-eslint/naming-convention, no-underscore-dangle, id-blacklist, id-match
        this._addedFormControls = {};
        // define non enumerable properties so these are omitted in JSON.stringify.
        Object.defineProperty(this, '$formGroup', {
            get: this.getFormGroup,
            enumerable: false
        });
        Object.defineProperty(this, '_formGroup', {
            enumerable: false,
            writable: true
        });
        Object.defineProperty(this, 'addedFormControls', {
            get: this.getAddedFormControls,
            enumerable: false
        });
        Object.defineProperty(this, '_addedFormControls', {
            enumerable: false,
            writable: true
        });
    }
    static clearFormArray(formGroup, key) {
        if (formGroup) {
            const formArray = formGroup.controls[key];
            for (let i = formArray.length - 1; i >= 0; i--) {
                formArray.removeAt(i);
            }
            return formArray;
        }
    }
    /**
     * add one or more additional validators to the control
     * @param key Name of the control (is the same as the name of the attached model property)
     * @param validators Validator(s) to add to the control
     */
    addValidatorToControl(key, validators) {
        const control = this.$formGroup.controls[key];
        const vals = validators instanceof Array ? validators : [validators];
        if (control.validator) {
            vals.push(control.validator);
        }
        control.setValidators(vals);
    }
    /**
     * add a new form control of type FormControl or FormGroup to this model.
     * Note: arrays (FormArray) are not supported.
     */
    addFormControl(key, control) {
        const existingControl = this.$formGroup.controls[key];
        if (!existingControl) {
            this.$formGroup.addControl(key, control);
            this._addedFormControls[key] = control;
        }
        else {
            // if a control with the given key exists, replace it (the actual given control might have been changed)
            this.$formGroup.setControl(key, control);
        }
    }
    // eslint-disable-next-line @typescript-eslint/ban-types
    getAddedFormControls() {
        return this._addedFormControls;
    }
    /**
     * set values in model properties for added form controls
     * Note: arrays (FormArray) are not supported.
     */
    setValuesInAddedPropertiesOfAttachedFormControls(values, useFormGroupValuesToModel) {
        const rawValues = this.getValuesToUse(values, useFormGroupValuesToModel);
        for (const key in this.addedFormControls) {
            if (rawValues[key]) {
                if (useFormGroupValuesToModel) {
                    const control = this.addedFormControls[key];
                    if (control instanceof FormControl) {
                        this[key] = rawValues[key];
                    }
                    else if (control instanceof FormGroup) {
                        this[key].setValues(rawValues[key], useFormGroupValuesToModel);
                    }
                    else if (control instanceof FormArray) {
                        throw new Error(`control of type FormArray not supported here`);
                    }
                    else {
                        throw new Error(`control of type ${control} not supported here`);
                    }
                }
                else {
                    this[key] = rawValues[key];
                }
            }
        }
    }
    /**
     * set values in added form controls
     * Note: arrays (FormArray) are not supported.
     */
    setFormGroupValuesInAddedFormControls() {
        // eslint-disable-next-line guard-for-in
        for (const key in this.addedFormControls) {
            const control = this.addedFormControls[key];
            if (control instanceof FormControl) {
                control.setValue(this[key]);
            }
            else if (control instanceof FormGroup) {
                this[key].setFormGroupValues();
            }
            else if (control instanceof FormArray) {
                throw new Error(`control of type FormArray not supported here`);
            }
            else {
                throw new Error(`control of type ${control} not supported here`);
            }
        }
    }
    fillModelArray(object, key, values, useFormGroupValuesToModel, 
    // eslint-disable-next-line @typescript-eslint/ban-types
    subTypeFactoryFn, 
    // eslint-disable-next-line no-undef-init
    type = undefined) {
        if (values) {
            object[key] = new Array();
            for (const value of values) {
                if (type) {
                    if (this.isSubType(value)) {
                        const subTypeInstance = subTypeFactoryFn(value, useFormGroupValuesToModel);
                        object[key].push(subTypeInstance);
                    }
                    else {
                        object[key].push(new type(value, useFormGroupValuesToModel));
                    }
                }
                else {
                    object[key].push(value);
                }
            }
            // generate FormArray control elements
            // this.fillFormArray<T>(key, object[key], type);
        }
    }
    isSubType(value) {
        // eslint-disable-next-line no-prototype-builtins
        return value.hasOwnProperty('$type') && value.$type;
    }
    getValuesToUse(values, useFormGroupValuesToModel) {
        let result = values;
        if (useFormGroupValuesToModel) {
            if (this.hasFormGroup(values)) {
                result = values.$formGroup.getRawValue();
            }
            else if (values instanceof FormGroup) {
                result = values.getRawValue();
            }
        }
        return result;
    }
    hasFormGroup(values) {
        return !!values.$formGroup;
    }
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    fillFormArray(key, modelValues, 
    // eslint-disable-next-line no-undef-init
    type = undefined) {
        const formArray = BaseModel.clearFormArray(this.$formGroup, key);
        for (const modelValue of modelValues) {
            if (type) {
                modelValue.setFormGroupValues();
                formArray.push(modelValue.$formGroup);
            }
            else {
                const formControl = new FormControl(modelValue);
                formArray.push(formControl);
            }
        }
    }
    /**
     * Lässt in einem BaseModel nur die als "dirty" markierten Felder des zugehörigen FormGroups zurück, und löscht den Rest
     * => Es bleibt ein Delta-Objekt mit allen Neuerungen übrig
     */
    generateDelta() {
        // eslint-disable-next-line @typescript-eslint/ban-types
        function getDirtyState(form) {
            // eslint-disable-next-line @typescript-eslint/ban-types
            return Object.keys(form.controls).reduce((dirtyState, controlKey) => {
                const control = form.controls[controlKey];
                if (!control.dirty) {
                    return dirtyState;
                }
                if (control instanceof FormGroup) {
                    return Object.assign(Object.assign({}, dirtyState), { [controlKey]: getDirtyState(control) });
                }
                if (control instanceof FormArray) {
                    return control.controls
                        .filter((c) => {
                        const tmp = getDirtyState(c);
                        return Object.entries(tmp).length === 0 ? false : true;
                    })
                        .map((c) => {
                        getDirtyState(c);
                    });
                }
                return Object.assign(Object.assign({}, dirtyState), { [controlKey]: control.value });
            }, {});
        }
        return getDirtyState(this._formGroup);
    }
    /**
     * this protected method casts to, with parameter called typeStr of type string and value of type any
     * result can be of type any
     * see implementation for full documentation
     */
    castTo(typeStr, value) {
        if (!(value === null || value === undefined)) {
            if (typeStr === 'number') {
                return parseFloat(value);
            }
            if (typeStr === 'Date') {
                // isses schon ein Date?
                if (value instanceof Date) {
                    return value;
                }
                // numbers auch zum Date casten
                if (typeof value === 'number') {
                    return new Date(value);
                }
                // nein? dann mach zu Date!
                const pattern = /^(-?(?:[1-9][0-9]*)?[0-9]{4})-(1[0-2]|0[1-9])-(3[01]|0[1-9]|[12][0-9])T(2[0-3]|[01][0-9]):([0-5][0-9]):([0-5][0-9])(\.[0-9]+)?(Z){1}$/g;
                if (value.match && value.match(pattern)) {
                    return Date.parse(value);
                }
                else {
                    // invalid utc ISO date
                    console.error('Datum konnte nicht verarbeitet werden: ', value);
                    return value;
                }
            }
        }
        return value;
    }
}

/**
 * DOCUMENTATION
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * OpenAPI spec version: 1.0.0
 * Contact: contact-email@something.io
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
/**
 * Generated Model Class for Model "User"
 *
 */
class User extends BaseModel {
    /**
     * constructor
     * @param values Can be used to set a webapi response or formValues to this newly constructed model
     * @useFormGroupValuesToModel if true use formValues
     */
    constructor(values, useFormGroupValuesToModel = false) {
        super();
        this.MODEL = 'User';
        if (values) {
            this.setValues(values, useFormGroupValuesToModel);
        }
        // define non enumerable properties so these are omitted in JSON.stringify.
        Object.defineProperty(this, 'MODEL', {
            enumerable: false,
            writable: false
        });
    }
    /**
     * set the values.
     * @param values Can be used to set a webapi response to this newly constructed model
     */
    setValues(values, useFormGroupValuesToModel = false) {
        if (values) {
            const rawValues = this.getValuesToUse(values, useFormGroupValuesToModel);
            this.id = this.castTo('string', rawValues.id);
            this.username = this.castTo('string', rawValues.username);
            this.email = this.castTo('string', rawValues.email);
            this.provider = this.castTo('string', rawValues.provider);
            this.confirmed = this.castTo('boolean', rawValues.confirmed);
            this.blocked = this.castTo('boolean', rawValues.blocked);
            this.role = this.castTo('any', rawValues.role);
            this.created_by = this.castTo('any', rawValues.created_by);
            this.updated_by = this.castTo('any', rawValues.updated_by);
            // set values in model properties for added formControls
            super.setValuesInAddedPropertiesOfAttachedFormControls(values, useFormGroupValuesToModel);
        }
    }
    /**
     * returns the FormGroup of that model
     */
    getFormGroup() {
        if (!this._formGroup) {
            this._formGroup = new FormGroup({
                id: new FormControl(this.id, [Validators.required]),
                username: new FormControl(this.username, [Validators.required]),
                email: new FormControl(this.email, [Validators.required]),
                provider: new FormControl(this.provider, []),
                confirmed: new FormControl(this.confirmed, []),
                blocked: new FormControl(this.blocked, []),
                role: new FormControl(this.role, []),
                created_by: new FormControl(this.created_by, []),
                updated_by: new FormControl(this.updated_by, [])
            });
        }
        return this._formGroup;
    }
    /**
     * set the FormGroup values to the model values.
     */
    setFormGroupValues() {
        this.$formGroup.controls.id.setValue(this.id);
        this.$formGroup.controls.username.setValue(this.username);
        this.$formGroup.controls.email.setValue(this.email);
        this.$formGroup.controls.provider.setValue(this.provider);
        this.$formGroup.controls.confirmed.setValue(this.confirmed);
        this.$formGroup.controls.blocked.setValue(this.blocked);
        this.$formGroup.controls.role.setValue(this.role);
        this.$formGroup.controls.created_by.setValue(this.created_by);
        this.$formGroup.controls.updated_by.setValue(this.updated_by);
        // set formValues in added formControls
        super.setFormGroupValuesInAddedFormControls();
    }
    /**
     * checks, if attribute is required for this model
     */
    isRequired(attribute) {
        switch (attribute) {
            case 'id':
                return true;
            case 'username':
                return true;
            case 'email':
                return true;
            case 'provider':
                return false;
            case 'confirmed':
                return false;
            case 'blocked':
                return false;
            case 'role':
                return false;
            case 'created_by':
                return false;
            case 'updated_by':
                return false;
            default:
                return false;
        }
    }
}
User.MODEL = 'User';

const routes = [
    {
        path: '',
        children: [
            {
                path: 'login',
                component: DefaultLoginComponent
            },
            {
                path: 'register',
                component: DefaultRegisterComponent
            },
            {
                path: 'logout',
                component: DefaultLogoutComponent
            },
            {
                path: 'request-password',
                component: DefaultRequestPasswordComponent
            },
            {
                path: 'reset-password',
                component: DefaultResetPasswordComponent
            },
            {
                path: 'providers',
                canActivateChild: [TokenGuard],
                children: [
                    {
                        path: 'github'
                    },
                    {
                        path: 'google'
                    },
                    {
                        path: 'microsoft'
                    }
                    // TODO: Add more providers
                ]
            },
            {
                path: 'profile',
                canActivateChild: [AuthGuard],
                component: ProfileComponent
            }
        ]
    }
];
class StrapiAuthRoutingModule {
}
StrapiAuthRoutingModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: StrapiAuthRoutingModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
StrapiAuthRoutingModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: StrapiAuthRoutingModule, imports: [i1$1.RouterModule], exports: [RouterModule] });
StrapiAuthRoutingModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: StrapiAuthRoutingModule, imports: [[RouterModule.forChild(routes)], RouterModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.1", ngImport: i0, type: StrapiAuthRoutingModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [RouterModule.forChild(routes)],
                    exports: [RouterModule]
                }]
        }] });

/*
 * Public API Surface of strapi-auth
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AuthComponents, AuthGuard, AuthInterceptor, AuthService, BaseModel, ConfigServiceInjector as ConfigService, DefaultLoginComponent, DefaultLogoutComponent, DefaultRegisterComponent, DefaultRequestPasswordComponent, DefaultResetPasswordComponent, LanguageService, LoginBaseComponent, LogoutBaseComponent, ProfileComponent, RegisterBaseComponent, RequestPasswordBaseComponent, ResetPasswordBaseComponent, StrapiAuthModule, StrapiAuthRoutingModule, TemplateService, TokenGuard, TokenService, User, ValidationComponent };
//# sourceMappingURL=ngx-strapi-auth.mjs.map
