import { ValidatorFn } from '@angular/forms';
import { FormControl, FormGroup } from '@angular/forms';
export declare abstract class BaseModel {
    constructor();
    /**
     * use $formGroup in angular's formBuilder to make a model driven (reactive) form.
     *   this.form = this.formBuilder.group({
     *       pet: this.pet.$formGroup,
     *   });
     */
    $formGroup: FormGroup;
    protected _formGroup: FormGroup;
    addedFormControls: any;
    private _addedFormControls;
    private static clearFormArray;
    /**
     * set the values.
     * @param values Can be used to set a webapi response to this newly constructed model
     */
    abstract setValues(values: any): void;
    /**
     * set the FormGroup values to the model values.
     */
    abstract setFormGroupValues(): void;
    protected abstract getFormGroup(): FormGroup;
    /**
     * add one or more additional validators to the control
     * @param key Name of the control (is the same as the name of the attached model property)
     * @param validators Validator(s) to add to the control
     */
    addValidatorToControl(key: string, validators: ValidatorFn | ValidatorFn[]): void;
    /**
     * add a new form control of type FormControl or FormGroup to this model.
     * Note: arrays (FormArray) are not supported.
     */
    protected addFormControl(key: string, control: FormGroup | FormControl): void;
    protected getAddedFormControls(): {};
    /**
     * set values in model properties for added form controls
     * Note: arrays (FormArray) are not supported.
     */
    protected setValuesInAddedPropertiesOfAttachedFormControls(values: any, useFormGroupValuesToModel: boolean): void;
    /**
     * set values in added form controls
     * Note: arrays (FormArray) are not supported.
     */
    protected setFormGroupValuesInAddedFormControls(): void;
    protected fillModelArray<T>(object: BaseModel, key: string, values: T[], useFormGroupValuesToModel: boolean, subTypeFactoryFn: Function, type?: any): void;
    protected isSubType(value: any): boolean;
    protected getValuesToUse(values: any, useFormGroupValuesToModel: boolean): any;
    protected hasFormGroup(values: any): boolean;
    protected fillFormArray<T>(key: string, modelValues: any, type?: any): void;
    /**
     * Lässt in einem BaseModel nur die als "dirty" markierten Felder des zugehörigen FormGroups zurück, und löscht den Rest
     * => Es bleibt ein Delta-Objekt mit allen Neuerungen übrig
     */
    generateDelta(): any;
    /**
     * this protected method casts to, with parameter called typeStr of type string and value of type any
     * result can be of type any
     * see implementation for full documentation
     */
    protected castTo(typeStr: string, value: any): any;
}
